@@ -20,7 +20,7 @@
  * audio_directx_out.c, direct sound audio output plugin for xine
  * by Matthew Grooms <elon@altavista.com>
  *
- * $Id: audio_directx_out.c,v 1.14 2006/06/02 22:18:56 dsalt Exp $
+ * $Id: audio_directx_out.c,v 1.17 2006/09/21 15:01:08 valtri Exp $
  */
 
 /*
@@ -793,6 +793,8 @@ static ao_driver_t *open_plugin (audio_driver_class_t *class_gen, const void *da
   ao_directx_t    *ao_directx;
   
   ao_directx = ( ao_directx_t * ) xine_xmalloc( sizeof( ao_directx_t ) );
+  if (!ao_directx)
+    return NULL;
   
   lprintf("open_plugin(%08x, %08x) Enter\n", (unsigned long)class_gen, (unsigned long)data);
   lprintf("open_plugin: ao_directx=%08x\n", (unsigned long)ao_directx);
@@ -842,6 +844,8 @@ static void *init_class (xine_t *xine, void *data) {
    * from this point on, nothing should go wrong anymore
    */
   audiox = (audiox_class_t *) xine_xmalloc (sizeof (audiox_class_t));
+  if (!audiox)
+    return NULL;
   
   audiox->driver_class.open_plugin     = open_plugin;
   audiox->driver_class.get_identifier  = get_identifier;
@@ -863,7 +867,7 @@ static const ao_info_t ao_info_directx = {
 /*
  * exported plugin catalog entry
  */
-const plugin_info_t xine_plugin_info[] = {
+const plugin_info_t xine_plugin_info[] EXPORTED = {
   /* type, API, "name", version, special_info, init_function */  
   { PLUGIN_AUDIO_OUT, AO_DIRECTX_IFACE_VERSION, "directx", XINE_VERSION_CODE, &ao_info_directx, init_class },
   { PLUGIN_NONE, 0, "", 0, NULL, NULL }
