@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: audio_esd_out.c,v 1.33 2006/06/02 22:18:56 dsalt Exp $
+ * $Id: audio_esd_out.c,v 1.35 2006/07/16 16:18:09 dsalt Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -523,10 +523,15 @@ static ao_driver_t *open_plugin (audio_driver_class_t *class_gen,
 
   esd_close(audio_fd);
 
-
   this                     = (esd_driver_t *) xine_xmalloc (sizeof (esd_driver_t));
+  if (!this)
+    return NULL;
   this->xine               = class->xine;
   this->pname              = strdup("xine esd audio output plugin");
+  if (!this->pname) {
+    free (this);
+    return NULL;
+  }
   this->output_sample_rate = 0;
   this->server_sample_rate = server_sample_rate;
   this->audio_fd           = -1;
@@ -581,6 +586,8 @@ static void *init_class (xine_t *xine, void *data) {
   esd_class_t        *this;
 
   this = (esd_class_t *) xine_xmalloc (sizeof (esd_class_t));
+  if (!this)
+    return NULL;
 
   this->driver_class.open_plugin     = open_plugin;
   this->driver_class.get_identifier  = get_identifier;
@@ -600,7 +607,7 @@ static const ao_info_t ao_info_esd = {
  * exported plugin catalog entry
  */
 
-const plugin_info_t xine_plugin_info[] = {
+const plugin_info_t xine_plugin_info[] EXPORTED = {
   /* type, API, "name", version, special_info, init_function */  
   { PLUGIN_AUDIO_OUT, AO_OUT_ESD_IFACE_VERSION, "esd", XINE_VERSION_CODE, &ao_info_esd, init_class },
   { PLUGIN_NONE, 0, "", 0, NULL, NULL }
