@@ -19,7 +19,7 @@
  */
 
 /*
- * $Id: demux_avi.c,v 1.228 2006/07/10 22:08:13 dgp85 Exp $
+ * $Id: demux_avi.c,v 1.232 2007/03/29 19:24:18 dgp85 Exp $
  *
  * demultiplexer for avi streams
  *
@@ -194,8 +194,8 @@ typedef struct{
   uint32_t  audio_posb;      /* Audio position: byte within chunk */
 
 
+  int       wavex_len;
   xine_waveformatex *wavex;
-  int    wavex_len;
 
   audio_index_t  audio_idx;
 
@@ -251,28 +251,27 @@ typedef struct demux_avi_s {
   input_plugin_t      *input;
   int                  status;
 
-  avi_t               *avi;
-
-  int                  no_audio;
-
   uint32_t             video_step;
   uint32_t             AVI_errno;
 
+  /* seeking args backup */
+  int                  seek_start_time;
+  off_t                seek_start_pos;
+
+  avi_t               *avi;
+
   idx_grow_t           idx_grow;
 
-  int                  streaming;
-  int                  last_index_entry_type;
-  int                  has_index;
-  
-  /* seeking args backup */
-  int                  seek_request;
-  off_t                seek_start_pos;
-  int                  seek_start_time;
+  uint8_t              no_audio:1;
+
+  uint8_t              streaming:1;
+  uint8_t              has_index:1;
+
+  uint8_t              seek_request:1;
 
   /* discontinuity detection (only at seek) */
-  int                  send_newpts;
-  int                  buf_flag_seek;
-  
+  uint8_t              buf_flag_seek:1;
+  uint8_t              send_newpts:1;
 } demux_avi_t ;
 
 typedef struct {
@@ -1392,7 +1391,7 @@ static avi_t *AVI_init(demux_avi_t *this) {
   AVI->video_posf = 0;
   AVI->video_posb = 0;
 
-  lprintf("done, pos=%lld, AVI->movi_start=%" PRIdMAX "\n", this->input->get_current_pos(this->input), (intmax_t)AVI->movi_start);
+  lprintf("done, pos=%"PRId64", AVI->movi_start=%" PRIdMAX "\n", this->input->get_current_pos(this->input), (intmax_t)AVI->movi_start);
   return AVI;
 }
 
@@ -2259,7 +2258,7 @@ static demux_plugin_t *open_plugin (demux_class_t *class_gen, xine_stream_t *str
   break;
 
   case METHOD_BY_EXTENSION: {
-    char *extensions, *mrl;
+    const char *extensions, *mrl;
 
     mrl = input->get_mrl (input);
     extensions = class_gen->get_extensions (class_gen);
@@ -2316,19 +2315,19 @@ static demux_plugin_t *open_plugin (demux_class_t *class_gen, xine_stream_t *str
  * demux avi class
  */
 
-static char *get_description (demux_class_t *this_gen) {
+static const char *get_description (demux_class_t *this_gen) {
   return "AVI/RIFF demux plugin";
 }
 
-static char *get_identifier (demux_class_t *this_gen) {
+static const char *get_identifier (demux_class_t *this_gen) {
   return "AVI";
 }
 
-static char *get_extensions (demux_class_t *this_gen) {
+static const char *get_extensions (demux_class_t *this_gen) {
   return "avi";
 }
 
-static char *get_mimetypes (demux_class_t *this_gen) {
+static const char *get_mimetypes (demux_class_t *this_gen) {
   return "video/msvideo: avi: AVI video;"
          "video/x-msvideo: avi: AVI video;";
 }
