@@ -19,7 +19,7 @@
  */
 
 /*
- * $Id: demux_eawve.c,v 1.28 2004/06/13 21:28:52 miguelfreitas Exp $
+ * $Id: demux_eawve.c,v 1.29 2007/01/19 00:26:40 dgp85 Exp $
  *
  * demux_eawve.c, Demuxer plugin for Electronic Arts' WVE file format
  *
@@ -370,7 +370,7 @@ static demux_plugin_t* open_plugin(demux_class_t *class_gen, xine_stream_t *stre
   switch (stream->content_detection_method) {
 
   case METHOD_BY_EXTENSION: {
-    char *extensions, *mrl;
+    const char *extensions, *mrl;
 
     mrl = input->get_mrl (input);
     extensions = class_gen->get_extensions (class_gen);
@@ -400,19 +400,19 @@ static demux_plugin_t* open_plugin(demux_class_t *class_gen, xine_stream_t *stre
   return &this->demux_plugin;
 }
 
-static char *get_description(demux_class_t *this_gen){
+static const char *get_description(demux_class_t *this_gen){
   return "Electronics Arts WVE format demux plugin";
 }
 
-static char *get_identifier(demux_class_t *this_gen){
+static const char *get_identifier(demux_class_t *this_gen){
   return "EA WVE";
 }
 
-static char *get_extensions(demux_class_t *this_gen){
+static const char *get_extensions(demux_class_t *this_gen){
   return "wve";
 }
 
-static char *get_mimetypes(demux_class_t *this_gen){
+static const char *get_mimetypes(demux_class_t *this_gen){
   return NULL;
 }
 
