@@ -19,7 +19,7 @@
  */
 
 /*
- * $Id: demux_image.c,v 1.23 2006/06/02 22:18:56 dsalt Exp $
+ * $Id: demux_image.c,v 1.26 2007/01/19 00:26:40 dgp85 Exp $
  *
  * image dummy demultiplexer
  */
@@ -120,6 +120,13 @@ static int demux_image_seek (demux_plugin_t *this_gen,
 
   demux_image_t *this = (demux_image_t *) this_gen;
 
+  /* delay finished event for presentation mode.
+   * -1 => wait forever
+   * 0  => do not wait
+   * xx => wait xx/10 seconds
+   */
+  xine_set_param (this->stream, XINE_PARAM_DELAY_FINISHED_EVENT, -1);
+
   return this->status;
 }
 
@@ -170,7 +177,7 @@ static demux_plugin_t *open_plugin (demux_class_t *class_gen,
   break;
 
   case METHOD_BY_EXTENSION: {
-    char *extensions, *mrl;
+    const char *extensions, *mrl;
 
     mrl = input->get_mrl (input);
     extensions = class_gen->get_extensions (class_gen);
@@ -218,19 +225,19 @@ static demux_plugin_t *open_plugin (demux_class_t *class_gen,
  * image demuxer class
  */
 
-static char *get_description (demux_class_t *this_gen) {
+static const char *get_description (demux_class_t *this_gen) {
   return "image demux plugin";
 }
  
-static char *get_identifier (demux_class_t *this_gen) {
+static const char *get_identifier (demux_class_t *this_gen) {
   return "imagedmx";
 }
 
-static char *get_extensions (demux_class_t *this_gen) {
+static const char *get_extensions (demux_class_t *this_gen) {
   return "png gif jpg jpeg";
 }
 
-static char *get_mimetypes (demux_class_t *this_gen) {
+static const char *get_mimetypes (demux_class_t *this_gen) {
   return NULL;
 }
 
@@ -264,7 +271,7 @@ static const demuxer_info_t demux_info_image = {
   11                       /* priority */
 };
 
-const plugin_info_t xine_plugin_info[] = {
+const plugin_info_t xine_plugin_info[] EXPORTED = {
   /* type, API, "name", version, special_info, init_function */
   { PLUGIN_DEMUX, 26, "image", XINE_VERSION_CODE, &demux_info_image, init_class },
   { PLUGIN_NONE, 0, "", 0, NULL, NULL }
