@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 the xine project
+ * Copyright (C) 2000-2003 the xine project
  *
  * This file is part of xine, a free video player.
  *
@@ -16,12 +16,14 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
- *
+ */
+
+/*
  * Interplay MVE File Demuxer by Mike Melanson (melanson@pcisys.net)
  * For more information regarding the Interplay MVE file format, visit:
  *   http://www.pcisys.net/~melanson/codecs/
  *
- * $Id: demux_ipmovie.c,v 1.6 2003/01/26 15:56:21 tmmm Exp $
+ * $Id: demux_ipmovie.c,v 1.27 2007/02/20 00:34:55 dgp85 Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -34,19 +36,18 @@
 #include <string.h>
 #include <stdlib.h>
 
+#define LOG_MODULE "demux_ipmovie"
+#define LOG_VERBOSE
+/*
+#define LOG
+*/
+
 #include "xine_internal.h"
 #include "xineutils.h"
 #include "compat.h"
 #include "demux.h"
 #include "bswap.h"
-
-/* debugging support */
-#define DEBUG_IPMOVIE 0
-#if DEBUG_IPMOVIE
-#define debug_ipmovie printf
-#else
-static inline void debug_ipmovie(const char *format, ...) { }
-#endif
+#include "group_games.h"
 
 #define IPMOVIE_SIGNATURE "Interplay MVE File\x1A\0"
 #define IPMOVIE_SIGNATURE_SIZE 20
@@ -88,53 +89,34 @@ static inline void debug_ipmovie(const char *format, ...) { }
 #define PALETTE_COUNT 256
 
 typedef struct {
-
   demux_plugin_t       demux_plugin;
 
   xine_stream_t       *stream;
-
-  config_values_t     *config;
-
   fifo_buffer_t       *video_fifo;
   fifo_buffer_t       *audio_fifo;
-
   input_plugin_t      *input;
-
-  pthread_t            thread;
-  int                  thread_running;
-  pthread_mutex_t      mutex;
-  int                  send_end_buffers;
-
-  off_t                data_start;
-  off_t                data_size;
   int                  status;
 
-  unsigned int         fps;
+  off_t                data_size;
+
+  float                fps;
   unsigned int         frame_pts_inc;
 
-  unsigned int         video_width;
-  unsigned int         video_height;
+  xine_bmiheader       bih;
+  xine_waveformatex    wave;
+
   int64_t              video_pts;
-  unsigned int         audio_bits;
-  unsigned int         audio_channels;
-  unsigned int         audio_sample_rate;
   unsigned int         audio_type;
   unsigned int         audio_frame_count;
 
   palette_entry_t      palette[PALETTE_COUNT];
-
-  char                 last_mrl[1024];
-
+  unsigned char       *decode_map;
+  int                  decode_map_size;
+  int                  new_palette;
 } demux_ipmovie_t;
 
 typedef struct {
-
   demux_class_t     demux_class;
-
-  /* class-wide, global variables here */
-
-  xine_t           *xine;
-  config_values_t  *config;
 } demux_ipmovie_class_t;
 
 /* This function loads and processes a single chunk in an IP movie file.
@@ -150,11 +132,13 @@ static int process_ipmovie_chunk(demux_ipmovie_t *this) {
   int opcode_size;
   unsigned char scratch[1024];
   int i, j;
-  int first_color, last_color;
+  int first_color, color_count;
   int audio_flags;
   buf_element_t *buf = NULL;
   off_t current_file_pos;
   int64_t audio_pts = 0;
+  int decode_map_index;
+  int decode_map_size_countdown;
 
   /* read the next chunk, wherever the file happens to be pointing */
   if (this->input->read(this->input, chunk_preamble, CHUNK_PREAMBLE_SIZE) !=
@@ -163,37 +147,36 @@ static int process_ipmovie_chunk(demux_ipmovie_t *this) {
   chunk_size = LE_16(&chunk_preamble[0]);
   chunk_type = LE_16(&chunk_preamble[2]);
 
-  debug_ipmovie ("ipmovie: chunk type 0x%04X, 0x%04X bytes: ", 
-    chunk_type, chunk_size);
+  lprintf("chunk type 0x%04X, 0x%04X bytes:\n", chunk_type, chunk_size);
 
   switch (chunk_type) {
 
     case CHUNK_INIT_AUDIO:
-      debug_ipmovie ("initialize audio\n");
+      lprintf("initialize audio\n");
       break;
 
     case CHUNK_AUDIO_ONLY:
-      debug_ipmovie ("audio only\n");
+      lprintf("audio only\n");
       break;
 
     case CHUNK_INIT_VIDEO:
-      debug_ipmovie ("initialize video\n");
+      lprintf("initialize video\n");
       break;
 
     case CHUNK_VIDEO:
-      debug_ipmovie ("video (and audio)\n");
+      lprintf("video (and audio)\n");
       break;
 
     case CHUNK_SHUTDOWN:
-      debug_ipmovie ("shutdown\n");
+      lprintf("shutdown\n");
       break;
 
     case CHUNK_END:
-      debug_ipmovie ("end\n");
+      lprintf("end\n");
       break;
 
     default:
-      debug_ipmovie ("invalid chunk\n");
+      lprintf("invalid chunk\n");
       chunk_type = CHUNK_BAD;
       break;
 
@@ -215,28 +198,28 @@ static int process_ipmovie_chunk(demux_ipmovie_t *this) {
     chunk_size -= OPCODE_PREAMBLE_SIZE;
     chunk_size -= opcode_size;
     if (chunk_size < 0) {
-      printf ("demux_ipmovie: chunk_size countdown just went negative\n");
+      lprintf("chunk_size countdown just went negative\n");
       chunk_type = CHUNK_BAD;
       break;
     }
-    debug_ipmovie ("  opcode type %02X, version %d, 0x%04X bytes: ",
+    lprintf("opcode type %02X, version %d, 0x%04X bytes:\n",
       opcode_type, opcode_version, opcode_size);
     switch (opcode_type) {
 
       case OPCODE_END_OF_STREAM:
-        debug_ipmovie ("end of stream\n");
+        lprintf("end of stream\n");
         this->input->seek(this->input, opcode_size, SEEK_CUR);
         break;
 
       case OPCODE_END_OF_CHUNK:
-        debug_ipmovie ("end of chunk\n");
+        lprintf("end of chunk\n");
         this->input->seek(this->input, opcode_size, SEEK_CUR);
         break;
 
       case OPCODE_CREATE_TIMER:
-        debug_ipmovie ("create timer\n");
+        lprintf("create timer\n");
         if ((opcode_version > 0) || (opcode_size > 6)) {
-          printf ("demux_ipmovie: bad create_timer opcode\n");
+          lprintf("bad create_timer opcode\n");
           chunk_type = CHUNK_BAD;
           break;
         }
@@ -245,17 +228,16 @@ static int process_ipmovie_chunk(demux_ipmovie_t *this) {
           chunk_type = CHUNK_BAD;
           break;
         }
-        this->fps = 1000000 / (LE_32(&scratch[0]) * LE_16(&scratch[4]));
-this->fps++;  /* above calculation usually yields 14.9; we need 15 */
-        this->frame_pts_inc = 90000 / this->fps;
-        debug_ipmovie ("    %d frames/second (timer div = %d, subdiv = %d)\n",
+        this->fps = 1000000.0 / (LE_32(&scratch[0]) * LE_16(&scratch[4]));
+        this->frame_pts_inc = (int)(90000.0 / this->fps);
+        lprintf("%.1f frames/second (timer div = %d, subdiv = %d)\n",
           this->fps, LE_32(&scratch[0]), LE_16(&scratch[4]));
         break;
 
       case OPCODE_INIT_AUDIO_BUFFERS:
-        debug_ipmovie ("initialize audio buffers\n");
+        lprintf("initialize audio buffers\n");
         if ((opcode_version > 1) || (opcode_size > 10)) {
-          printf ("demux_ipmovie: bad init_audio_buffers opcode\n");
+          lprintf("bad init_audio_buffers opcode\n");
           chunk_type = CHUNK_BAD;
           break;
         }
@@ -264,33 +246,34 @@ this->fps++;  /* above calculation usually yields 14.9; we need 15 */
           chunk_type = CHUNK_BAD;
           break;
         }
-        this->audio_sample_rate = LE_16(&scratch[4]);
+        this->wave.nSamplesPerSec = LE_16(&scratch[4]);
         audio_flags = LE_16(&scratch[2]);
         /* bit 0 of the flags: 0 = mono, 1 = stereo */
-        this->audio_channels = (audio_flags & 1) + 1;
+        this->wave.nChannels = (audio_flags & 1) + 1;
         /* bit 1 of the flags: 0 = 8 bit, 1 = 16 bit */
-        this->audio_bits = (((audio_flags >> 1) & 1) + 1) * 8;
+        this->wave.wBitsPerSample = (((audio_flags >> 1) & 1) + 1) * 8;
         /* bit 2 indicates compressed audio in version 1 opcode */
         if ((opcode_version == 1) && (audio_flags & 0x4))
           this->audio_type = BUF_AUDIO_INTERPLAY;
         else
           this->audio_type = BUF_AUDIO_LPCM_LE;
-        debug_ipmovie ("    audio: %d bits, %d Hz, %s, %s format\n",
-          this->audio_bits,
-          this->audio_sample_rate,
-          (this->audio_channels == 2) ? "stereo" : "mono",
+        lprintf("audio: %d bits, %d Hz, %s, %s format\n",
+          this->wave.wBitsPerSample,
+          this->wave.nSamplesPerSec,
+          (this->wave.nChannels == 2) ? "stereo" : "mono",
           (this->audio_type == BUF_AUDIO_LPCM_LE) ? "PCM" : "Interplay audio");
         break;
 
       case OPCODE_START_STOP_AUDIO:
-        debug_ipmovie ("start/stop audio\n");
+        lprintf("start/stop audio\n");
         this->input->seek(this->input, opcode_size, SEEK_CUR);
         break;
 
       case OPCODE_INIT_VIDEO_BUFFERS:
-        debug_ipmovie ("initialize video buffers\n");
+        lprintf("initialize video buffers\n");
+        if (this->decode_map) free(this->decode_map);
         if ((opcode_version > 2) || (opcode_size > 8)) {
-          printf ("demux_ipmovie: bad init_video_buffers opcode\n");
+          lprintf("bad init_video_buffers opcode\n");
           chunk_type = CHUNK_BAD;
           break;
         }
@@ -299,10 +282,14 @@ this->fps++;  /* above calculation usually yields 14.9; we need 15 */
           chunk_type = CHUNK_BAD;
           break;
         }
-        this->video_width = LE_16(&scratch[0]) * 8;
-        this->video_height = LE_16(&scratch[2]) * 8;
-        debug_ipmovie ("    video resolution: %d x %d\n",
-          this->video_width, this->video_height);
+        this->bih.biWidth = LE_16(&scratch[0]) * 8;
+        this->bih.biHeight = LE_16(&scratch[2]) * 8;
+        /* set up staging area for decode map */
+        this->decode_map_size = (this->bih.biWidth * this->bih.biHeight) /
+          (8 * 8) / 2;
+        this->decode_map = xine_xmalloc(this->decode_map_size);
+        lprintf("video resolution: %d x %d\n",
+          this->bih.biWidth, this->bih.biHeight);
         break;
 
       case OPCODE_UNKNOWN_06:
@@ -312,40 +299,42 @@ this->fps++;  /* above calculation usually yields 14.9; we need 15 */
       case OPCODE_UNKNOWN_13:
       case OPCODE_UNKNOWN_14:
       case OPCODE_UNKNOWN_15:
-        debug_ipmovie ("unknown (but documented) opcode %02X\n", opcode_type);
+        lprintf("unknown (but documented) opcode %02X\n", opcode_type);
         this->input->seek(this->input, opcode_size, SEEK_CUR);
         break;
 
       case OPCODE_SEND_BUFFER:
-        debug_ipmovie ("send buffer\n");
+        lprintf("send buffer\n");
         this->input->seek(this->input, opcode_size, SEEK_CUR);
         break;
 
       case OPCODE_AUDIO_FRAME:
-        debug_ipmovie ("audio frame\n");
+        lprintf("audio frame\n");
 
         current_file_pos = this->input->get_current_pos(this->input);
 
         /* figure out the number of audio frames */
-        if (this->audio_type == BUF_AUDIO_LPCM_LE)
+        if (this->audio_type == BUF_AUDIO_LPCM_LE) {
+          opcode_size -= 6;
           this->audio_frame_count +=
-            (opcode_size / this->audio_channels / (this->audio_bits / 8));
-        else
+            (opcode_size / this->wave.nChannels / (this->wave.wBitsPerSample / 8));
+          this->input->seek(this->input, 6, SEEK_CUR);
+        } else
           this->audio_frame_count +=
-            (opcode_size - 6) / this->audio_channels;
+            (opcode_size - 6) / this->wave.nChannels;
         audio_pts = 90000;
         audio_pts *= this->audio_frame_count;
-        audio_pts /= this->audio_sample_rate;
+        audio_pts /= this->wave.nSamplesPerSec;
 
-        debug_ipmovie ("    sending audio frame with pts %lld (%d audio frames)\n",
+        lprintf("sending audio frame with pts %"PRId64" (%d audio frames)\n",
           audio_pts, this->audio_frame_count);
 
         if(this->audio_fifo) {
           while (opcode_size) {
             buf = this->audio_fifo->buffer_pool_alloc (this->audio_fifo);
             buf->type = this->audio_type;
-            buf->extra_info->input_pos = current_file_pos;
-            buf->extra_info->input_length = this->data_size;
+            if( this->data_size )
+              buf->extra_info->input_normpos = (int)( (double) current_file_pos * 65535 / this->data_size);
             buf->extra_info->input_time = audio_pts / 90;
             buf->pts = audio_pts;
   
@@ -373,30 +362,30 @@ this->fps++;  /* above calculation usually yields 14.9; we need 15 */
         break;
 
       case OPCODE_SILENCE_FRAME:
-        debug_ipmovie ("silence frame\n");
+        lprintf("silence frame\n");
         this->input->seek(this->input, opcode_size, SEEK_CUR);
         break;
 
       case OPCODE_INIT_VIDEO_MODE:
-        debug_ipmovie ("initialize video mode\n");
+        lprintf("initialize video mode\n");
         this->input->seek(this->input, opcode_size, SEEK_CUR);
         break;
 
       case OPCODE_CREATE_GRADIENT:
-        debug_ipmovie ("create gradient\n");
+        lprintf("create gradient\n");
         this->input->seek(this->input, opcode_size, SEEK_CUR);
         break;
 
       case OPCODE_SET_PALETTE:
-        debug_ipmovie ("set palette\n");
+        lprintf("set palette\n");
         /* check for the logical maximum palette size 
          * (3 * 256 + 4 bytes) */
         if (opcode_size > 0x304) {
-          printf ("demux_ipmovie: set_palette opcode too large\n");
+          lprintf("set_palette opcode too large\n");
           chunk_type = CHUNK_BAD;
           break;
         }
-        if (this->input->read(this->input, scratch, opcode_size) != 
+        if (this->input->read(this->input, scratch, opcode_size) !=
           opcode_size) {
           chunk_type = CHUNK_BAD;
           break;
@@ -404,81 +393,94 @@ this->fps++;  /* above calculation usually yields 14.9; we need 15 */
 
         /* load the palette into internal data structure */
         first_color = LE_16(&scratch[0]);
-        last_color = LE_16(&scratch[2]);
+        color_count = LE_16(&scratch[2]);
         /* sanity check (since they are 16 bit values) */
-        if ((first_color > 0xFF) || (last_color > 0xFF)) {
-          printf ("demux_ipmovie: set_palette indices out of range (%d -> %d)\n",
-            first_color, last_color);
+        if ((first_color > 0xFF) || (first_color + color_count > 0x100)) {
+          lprintf("set_palette indices out of range (%d -> %d)\n",
+            first_color, first_color + color_count);
           chunk_type = CHUNK_BAD;
           break;
         }
         j = 4;  /* offset of first palette data */
-        for (i = first_color; i <= last_color; i++) {
+        for (i = first_color; i < first_color + color_count; i++) {
           this->palette[i].r = scratch[j++] * 4;
           this->palette[i].g = scratch[j++] * 4;
           this->palette[i].b = scratch[j++] * 4;
         }
+        this->new_palette = 1;
         break;
 
       case OPCODE_SET_PALETTE_COMPRESSED:
-        debug_ipmovie ("set palette compressed\n");
+        lprintf("set palette compressed\n");
         this->input->seek(this->input, opcode_size, SEEK_CUR);
         break;
 
       case OPCODE_SET_DECODING_MAP:
-        debug_ipmovie ("set decoding map\n");
+        lprintf("set decoding map\n");
 
         current_file_pos = this->input->get_current_pos(this->input);
-        debug_ipmovie ("    sending decoding map along with duration %d\n",
+        lprintf("sending decoding map along with duration %d\n",
           this->frame_pts_inc);
 
-        while (opcode_size) {
+        /* load the decode map into the staging area */
+        if (this->input->read(this->input, this->decode_map,
+          this->decode_map_size) != this->decode_map_size)
+          this->status = DEMUX_FINISHED;
+        break;
+
+      case OPCODE_VIDEO_DATA:
+        lprintf("set video data\n");
+
+        current_file_pos = this->input->get_current_pos(this->input);
+        lprintf("sending video data with pts %"PRId64"\n",
+          this->video_pts);
+
+        /* send off any new palette data */
+        if (this->new_palette) {
+          buf = this->video_fifo->buffer_pool_alloc (this->video_fifo);
+          buf->decoder_flags = BUF_FLAG_SPECIAL|BUF_FLAG_HEADER;
+          buf->decoder_info[1] = BUF_SPECIAL_PALETTE;
+          buf->decoder_info[2] = 256;
+          buf->decoder_info_ptr[2] = &this->palette;
+          buf->size = 0;
+          buf->type = BUF_VIDEO_INTERPLAY;
+          this->video_fifo->put (this->video_fifo, buf);
+          this->new_palette = 0;
+        }
+
+        /* send the decode map first */
+        decode_map_index = 0;
+        decode_map_size_countdown = this->decode_map_size;
+        while (decode_map_size_countdown) {
           buf = this->video_fifo->buffer_pool_alloc (this->video_fifo);
           buf->type = BUF_VIDEO_INTERPLAY;
-          buf->extra_info->input_pos = current_file_pos;
-          buf->extra_info->input_length = this->data_size;
+          if( this->data_size )
+            buf->extra_info->input_normpos = (int)( (double) current_file_pos * 65535 / this->data_size);
           buf->extra_info->input_time = this->video_pts / 90;
           buf->pts = this->video_pts;
 
-          if (opcode_size > buf->max_size)
+          if (decode_map_size_countdown > buf->max_size)
             buf->size = buf->max_size;
           else
-            buf->size = opcode_size;
-          opcode_size -= buf->size;
+            buf->size = decode_map_size_countdown;
+          decode_map_size_countdown -= buf->size;
 
-          if (this->input->read(this->input, buf->content, buf->size) !=
-            buf->size) {
-            buf->free_buffer(buf);
-            this->status = DEMUX_FINISHED;
-            break;
-          }
-
-          if (!opcode_size)
-            buf->decoder_flags |= BUF_FLAG_FRAME_END;
-
-          /* send the duration since it was not known when headers were sent */
-          buf->decoder_flags |= BUF_FLAG_FRAMERATE;
-          buf->decoder_info[0] = this->frame_pts_inc;
+          memcpy(buf->content, &this->decode_map[decode_map_index], buf->size);
+          decode_map_index += buf->size;
 
           this->video_fifo->put (this->video_fifo, buf);
         }
 
-        break;
-
-      case OPCODE_VIDEO_DATA:
-        debug_ipmovie ("set video data\n");
-
-        current_file_pos = this->input->get_current_pos(this->input);
-        debug_ipmovie ("    sending video data with pts %lld\n",
-          this->video_pts);
-
+        /* then send the video data */
         while (opcode_size) {
           buf = this->video_fifo->buffer_pool_alloc (this->video_fifo);
           buf->type = BUF_VIDEO_INTERPLAY;
-          buf->extra_info->input_pos = current_file_pos;
-          buf->extra_info->input_length = this->data_size;
+          if( this->data_size )
+            buf->extra_info->input_normpos = (int)( (double) current_file_pos * 65535 / this->data_size);
           buf->extra_info->input_time = this->video_pts / 90;
           buf->pts = this->video_pts;
+          buf->decoder_flags = BUF_FLAG_FRAMERATE;
+          buf->decoder_info[0] = this->frame_pts_inc;
 
           if (opcode_size > buf->max_size)
             buf->size = buf->max_size;
@@ -510,7 +512,7 @@ this->fps++;  /* above calculation usually yields 14.9; we need 15 */
         break;
 
       default:
-        debug_ipmovie (" *** unknown opcode type\n");
+        lprintf("*** unknown opcode type\n");
         chunk_type = CHUNK_BAD;
         break;
 
@@ -523,21 +525,19 @@ this->fps++;  /* above calculation usually yields 14.9; we need 15 */
 
 /* returns 1 if the MVE file was opened successfully, 0 otherwise */
 static int open_ipmovie_file(demux_ipmovie_t *this) {
-
   unsigned char signature[IPMOVIE_SIGNATURE_SIZE];
 
   this->audio_type = 0;
 
-  this->input->seek(this->input, 0, SEEK_SET);
-  if (this->input->read(this->input, signature, IPMOVIE_SIGNATURE_SIZE) !=
-    IPMOVIE_SIGNATURE_SIZE)
+  if (_x_demux_read_header(this->input, signature, IPMOVIE_SIGNATURE_SIZE) !=
+      IPMOVIE_SIGNATURE_SIZE)
     return 0;
 
   if (strncmp(signature, IPMOVIE_SIGNATURE, IPMOVIE_SIGNATURE_SIZE) != 0)
     return 0;
 
-  /* skip the 6 unknown bytes */
-  this->input->seek(this->input, 6, SEEK_CUR);
+  /* file is qualified; skip over the signature bytes (+ 6 unknown) in the stream */
+  this->input->seek(this->input, IPMOVIE_SIGNATURE_SIZE+6, SEEK_SET);
 
   /* process the first chunk which should be CHUNK_INIT_VIDEO */
   if (process_ipmovie_chunk(this) != CHUNK_INIT_VIDEO)
@@ -547,7 +547,7 @@ static int open_ipmovie_file(demux_ipmovie_t *this) {
   if (process_ipmovie_chunk(this) != CHUNK_INIT_AUDIO)
     return 0;
 
-  debug_ipmovie ("detected Interplay MVE file\n");
+  lprintf("detected Interplay MVE file\n");
   this->data_size = this->input->get_length(this->input);
   this->audio_frame_count = 0;
   this->video_pts = 0;
@@ -556,7 +556,6 @@ static int open_ipmovie_file(demux_ipmovie_t *this) {
 }
 
 static int demux_ipmovie_send_chunk(demux_plugin_t *this_gen) {
-
   demux_ipmovie_t *this = (demux_ipmovie_t *) this_gen;
 
   if (process_ipmovie_chunk(this) == CHUNK_BAD)
@@ -566,7 +565,6 @@ static int demux_ipmovie_send_chunk(demux_plugin_t *this_gen) {
 }
 
 static void demux_ipmovie_send_headers(demux_plugin_t *this_gen) {
-
   demux_ipmovie_t *this = (demux_ipmovie_t *) this_gen;
   buf_element_t *buf;
 
@@ -576,34 +574,30 @@ static void demux_ipmovie_send_headers(demux_plugin_t *this_gen) {
   this->status = DEMUX_OK;
 
   /* load stream information */
-  this->stream->stream_info[XINE_STREAM_INFO_HAS_VIDEO] = 1;
-  this->stream->stream_info[XINE_STREAM_INFO_HAS_AUDIO] = 0;
-  this->stream->stream_info[XINE_STREAM_INFO_VIDEO_WIDTH] = this->video_width;
-  this->stream->stream_info[XINE_STREAM_INFO_VIDEO_HEIGHT] = this->video_height;
+  _x_stream_info_set(this->stream, XINE_STREAM_INFO_HAS_VIDEO, 1);
+  _x_stream_info_set(this->stream, XINE_STREAM_INFO_HAS_AUDIO, 0);
+  _x_stream_info_set(this->stream, XINE_STREAM_INFO_VIDEO_WIDTH, this->bih.biWidth);
+  _x_stream_info_set(this->stream, XINE_STREAM_INFO_VIDEO_HEIGHT, this->bih.biHeight);
 
   /* send start buffers */
-  xine_demux_control_start(this->stream);
+  _x_demux_control_start(this->stream);
 
   /* send init info to video decoder */
+  this->bih.biSize = sizeof(xine_bmiheader);
   buf = this->video_fifo->buffer_pool_alloc (this->video_fifo);
-  buf->decoder_flags = BUF_FLAG_HEADER;
-  buf->decoder_info[0] = 0;
+  buf->decoder_flags = BUF_FLAG_HEADER|BUF_FLAG_STDHEADER|BUF_FLAG_FRAMERATE|
+                       BUF_FLAG_FRAME_END;
   /* bogus initial video_step, but we won't know for sure until we see
    * the first video frame; however, fps for these files is usually 15 */
-  buf->decoder_info[1] = 6000;
-  /* really be a rebel: No structure at all, just put the video width
-   * and height straight into the buffer, BE_16 format */
-  buf->content[0] = (this->video_width >> 8) & 0xFF;
-  buf->content[1] = (this->video_width >> 0) & 0xFF;
-  buf->content[2] = (this->video_height >> 8) & 0xFF;
-  buf->content[3] = (this->video_height >> 0) & 0xFF;
-  buf->size = 4;
+  buf->decoder_info[0] = 6000;
+  buf->size = sizeof(xine_bmiheader);
+  memcpy(buf->content, &this->bih, buf->size);
   buf->type = BUF_VIDEO_INTERPLAY;
   this->video_fifo->put (this->video_fifo, buf);
 
   /* send off the palette */
   buf = this->video_fifo->buffer_pool_alloc (this->video_fifo);
-  buf->decoder_flags = BUF_FLAG_SPECIAL;
+  buf->decoder_flags = BUF_FLAG_SPECIAL|BUF_FLAG_HEADER;
   buf->decoder_info[1] = BUF_SPECIAL_PALETTE;
   buf->decoder_info[2] = 256;
   buf->decoder_info_ptr[2] = &this->palette;
@@ -613,40 +607,45 @@ static void demux_ipmovie_send_headers(demux_plugin_t *this_gen) {
 
   /* send init info to the audio decoder */
   if ((this->audio_fifo) && (this->audio_type)) {
+    this->wave.nSamplesPerSec = this->wave.nSamplesPerSec;
+    this->wave.wBitsPerSample = this->wave.wBitsPerSample;
+    this->wave.nBlockAlign = (this->wave.wBitsPerSample / 8) * this->wave.nChannels;
+    this->wave.nAvgBytesPerSec = this->wave.nBlockAlign * this->wave.nSamplesPerSec;
+
     buf = this->audio_fifo->buffer_pool_alloc (this->audio_fifo);
     buf->type = this->audio_type;
-    buf->decoder_flags = BUF_FLAG_HEADER;
+    buf->decoder_flags = BUF_FLAG_HEADER|BUF_FLAG_STDHEADER|BUF_FLAG_FRAME_END;
     buf->decoder_info[0] = 0;
-    buf->decoder_info[1] = this->audio_sample_rate;
-    buf->decoder_info[2] = this->audio_bits;
-    buf->decoder_info[3] = this->audio_channels;
-    buf->size = 0;
+    buf->decoder_info[1] = this->wave.nSamplesPerSec;
+    buf->decoder_info[2] = this->wave.wBitsPerSample;
+    buf->decoder_info[3] = this->wave.nChannels;
+    buf->size = sizeof(this->wave);
+    memcpy(buf->content, &this->wave, buf->size);
     this->audio_fifo->put (this->audio_fifo, buf);
   }
 }
 
 static int demux_ipmovie_seek (demux_plugin_t *this_gen,
-                               off_t start_pos, int start_time) {
+                               off_t start_pos, int start_time, int playing) {
 
   demux_ipmovie_t *this = (demux_ipmovie_t *) this_gen;
 
   /* if thread is not running, initialize demuxer */
-  if( !this->stream->demux_thread_running ) {
+  if( !playing ) {
 
     /* send new pts */
-    xine_demux_control_newpts(this->stream, 0, 0);
+    _x_demux_control_newpts(this->stream, 0, 0);
 
     this->status = DEMUX_OK;
-
-    /* make sure to start just after the header and 6 unknown bytes */
-    this->input->seek(this->input, IPMOVIE_SIGNATURE_SIZE + 6, SEEK_SET);
   }
 
   return this->status;
 }
 
-static void demux_ipmovie_dispose (demux_plugin_t *this) {
+static void demux_ipmovie_dispose (demux_plugin_t *this_gen) {
+  demux_ipmovie_t *this = (demux_ipmovie_t *) this_gen;
 
+  free(this->decode_map);
   free(this);
 }
 
@@ -657,7 +656,6 @@ static int demux_ipmovie_get_status (demux_plugin_t *this_gen) {
 }
 
 static int demux_ipmovie_get_stream_length (demux_plugin_t *this_gen) {
-
   return 0;
 }
 
@@ -671,16 +669,10 @@ static int demux_ipmovie_get_optional_data(demux_plugin_t *this_gen,
 }
 
 static demux_plugin_t *open_plugin (demux_class_t *class_gen, xine_stream_t *stream,
-                                    input_plugin_t *input_gen) {
+                                    input_plugin_t *input) {
 
-  input_plugin_t *input = (input_plugin_t *) input_gen;
   demux_ipmovie_t    *this;
 
-  if (! (input->get_capabilities(input) & INPUT_CAP_SEEKABLE)) {
-    printf(_("demux_ipmovie.c: input not seekable, can not handle!\n"));
-    return NULL;
-  }
-
   this         = xine_xmalloc (sizeof (demux_ipmovie_t));
   this->stream = stream;
   this->input  = input;
@@ -691,16 +683,28 @@ static demux_plugin_t *open_plugin (demux_class_t *class_gen, xine_stream_t *str
   this->demux_plugin.dispose           = demux_ipmovie_dispose;
   this->demux_plugin.get_status        = demux_ipmovie_get_status;
   this->demux_plugin.get_stream_length = demux_ipmovie_get_stream_length;
-  this->demux_plugin.get_video_frame   = NULL;
-  this->demux_plugin.got_video_frame_cb= NULL;
   this->demux_plugin.get_capabilities  = demux_ipmovie_get_capabilities;
   this->demux_plugin.get_optional_data = demux_ipmovie_get_optional_data;
   this->demux_plugin.demux_class       = class_gen;
 
   this->status = DEMUX_FINISHED;
+  this->decode_map = NULL;
 
   switch (stream->content_detection_method) {
 
+  case METHOD_BY_EXTENSION: {
+    const char *extensions, *mrl;
+
+    mrl = input->get_mrl (input);
+    extensions = class_gen->get_extensions (class_gen);
+
+    if (!_x_demux_check_extension (mrl, extensions)) {
+      free (this);
+      return NULL;
+    }
+  }
+  /* falling through is intended */
+
   case METHOD_BY_CONTENT:
   case METHOD_EXPLICIT:
 
@@ -711,73 +715,40 @@ static demux_plugin_t *open_plugin (demux_class_t *class_gen, xine_stream_t *str
 
   break;
 
-  case METHOD_BY_EXTENSION: {
-    char *ending, *mrl;
-
-    mrl = input->get_mrl (input);
-
-    ending = strrchr(mrl, '.');
-
-    if (!ending) {
-      free (this);
-      return NULL;
-    }
-
-    if ((strncasecmp (ending, ".mve", 4)) &&
-        (strncasecmp (ending, ".mv8", 4))) {
-      free (this);
-      return NULL;
-    }
-
-    if (!open_ipmovie_file(this)) {
-      free (this);
-      return NULL;
-    }
-
-  }
-
-  break;
-
   default:
     free (this);
     return NULL;
   }
 
-  strncpy (this->last_mrl, input->get_mrl (input), 1024);
-
   return &this->demux_plugin;
 }
 
-static char *get_description (demux_class_t *this_gen) {
+static const char *get_description (demux_class_t *this_gen) {
   return "Interplay MVE Movie demux plugin";
 }
 
-static char *get_identifier (demux_class_t *this_gen) {
+static const char *get_identifier (demux_class_t *this_gen) {
   return "Interplay MVE";
 }
 
-static char *get_extensions (demux_class_t *this_gen) {
+static const char *get_extensions (demux_class_t *this_gen) {
   return "mve mv8";
 }
 
-static char *get_mimetypes (demux_class_t *this_gen) {
+static const char *get_mimetypes (demux_class_t *this_gen) {
   return NULL;
 }
 
 static void class_dispose (demux_class_t *this_gen) {
-
   demux_ipmovie_class_t *this = (demux_ipmovie_class_t *) this_gen;
 
   free (this);
 }
 
 void *demux_ipmovie_init_plugin (xine_t *xine, void *data) {
-
   demux_ipmovie_class_t     *this;
 
-  this         = xine_xmalloc (sizeof (demux_ipmovie_class_t));
-  this->config = xine->config;
-  this->xine   = xine;
+  this = xine_xmalloc (sizeof (demux_ipmovie_class_t));
 
   this->demux_class.open_plugin     = open_plugin;
   this->demux_class.get_description = get_description;
@@ -788,15 +759,3 @@ void *demux_ipmovie_init_plugin (xine_t *xine, void *data) {
 
   return this;
 }
-
-/*
- * exported plugin catalog entry
- */
-
-#if 0
-plugin_info_t xine_plugin_info[] = {
-  /* type, API, "name", version, special_info, init_function */
-  { PLUGIN_DEMUX, 20, "ipmovie", XINE_VERSION_CODE, NULL, demux_ipmovie_init_plugin },
-  { PLUGIN_NONE, 0, "", 0, NULL, NULL }
-};
-#endif
