@@ -19,7 +19,7 @@
  */
 
 /*
- * $Id: demux_mng.c,v 1.28 2006/07/10 22:08:13 dgp85 Exp $
+ * $Id: demux_mng.c,v 1.29 2007/01/19 00:26:40 dgp85 Exp $
  *
  * demux_mng.c, Demuxer plugin for Multiple-image Network Graphics format
  *
@@ -288,7 +288,7 @@ static demux_plugin_t* open_plugin(demux_class_t *class_gen, xine_stream_t *stre
     break;
 
     case METHOD_BY_EXTENSION: {
-      char *extensions, *mrl;
+      const char *extensions, *mrl;
 
       mrl = input->get_mrl(input);
       extensions = class_gen->get_extensions (class_gen);
@@ -336,19 +336,19 @@ static demux_plugin_t* open_plugin(demux_class_t *class_gen, xine_stream_t *stre
   return &this->demux_plugin;
 }
 
-static char *get_description(demux_class_t *this_gen){
+static const char *get_description(demux_class_t *this_gen){
   return "Multiple-image Network Graphics demux plugin";
 }
 
-static char *get_identifier(demux_class_t *this_gen){
+static const char *get_identifier(demux_class_t *this_gen){
   return "MNG";
 }
 
-static char *get_extensions(demux_class_t *this_gen){
+static const char *get_extensions(demux_class_t *this_gen){
   return "png mng";
 }
 
-static char *get_mimetypes(demux_class_t *this_gen){
+static const char *get_mimetypes(demux_class_t *this_gen){
   return "image/png: png: PNG image;"
          "image/x-png: png: PNG image;"
          "video/mng: mng: MNG animation;"
