@@ -19,7 +19,7 @@
  */
 
 /*
- * $Id: demux_rawdv.c,v 1.23.2.1 2005/04/20 17:21:05 mroi Exp $
+ * $Id: demux_rawdv.c,v 1.30 2007/01/19 00:26:40 dgp85 Exp $
  *
  * demultiplexer for raw dv streams
  */
@@ -202,6 +202,12 @@ static void demux_raw_dv_send_headers (demux_plugin_t *this_gen) {
     _x_stream_info_set(this->stream, XINE_STREAM_INFO_VIDEO_BITRATE,
                          PAL_FRAME_SIZE * PAL_FRAME_RATE * 8);
   }
+
+  _x_stream_info_set(this->stream, XINE_STREAM_INFO_VIDEO_WIDTH,
+                     bih->biWidth);
+  _x_stream_info_set(this->stream, XINE_STREAM_INFO_VIDEO_HEIGHT,
+                     bih->biHeight);
+
   bih->biSize = sizeof(xine_bmiheader);
   bih->biPlanes = 1;
   bih->biBitCount = 24;
@@ -312,6 +318,7 @@ static int demux_raw_dv_seek (demux_plugin_t *this_gen,
 
   _x_demux_control_newpts (this->stream, this->pts, BUF_FLAG_SEEK);
   
+  this->status = DEMUX_OK;
   return this->status;
 }
 
@@ -322,7 +329,10 @@ static void demux_raw_dv_dispose (demux_plugin_t *this_gen) {
 }
 
 static int demux_raw_dv_get_stream_length(demux_plugin_t *this_gen) {
-  return 0 ; /*FIXME: implement */
+  demux_raw_dv_t *this = (demux_raw_dv_t *) this_gen;
+
+  return (int)((int64_t) this->duration * this->input->get_length (this->input) /
+		  (this->frame_size * 90));
 }
 
 static uint32_t demux_raw_dv_get_capabilities(demux_plugin_t *this_gen) {
@@ -375,7 +385,7 @@ static demux_plugin_t *open_plugin (demux_class_t *class_gen, xine_stream_t *str
   break;
 
   case METHOD_BY_EXTENSION: {
-    char *extensions, *mrl;
+    const char *extensions, *mrl;
 
     mrl = input->get_mrl (input);
     extensions = class_gen->get_extensions (class_gen);
@@ -403,19 +413,19 @@ static demux_plugin_t *open_plugin (demux_class_t *class_gen, xine_stream_t *str
   return &this->demux_plugin;
 }
 
-static char *get_description (demux_class_t *this_gen) {
+static const char *get_description (demux_class_t *this_gen) {
   return "Raw DV Video stream";
 }
 
-static char *get_identifier (demux_class_t *this_gen) {
+static const char *get_identifier (demux_class_t *this_gen) {
   return "raw_dv";
 }
 
-static char *get_extensions (demux_class_t *this_gen) {
+static const char *get_extensions (demux_class_t *this_gen) {
   return "dv dif";
 }
 
-static char *get_mimetypes (demux_class_t *this_gen) {
+static const char *get_mimetypes (demux_class_t *this_gen) {
   return NULL;
 }
 
@@ -443,11 +453,11 @@ static void *init_plugin (xine_t *xine, void *data) {
 /*
  * exported plugin catalog entry
  */
-demuxer_info_t demux_info_raw_dv = {
+static const demuxer_info_t demux_info_raw_dv = {
   1                       /* priority */
 };
 
-plugin_info_t xine_plugin_info[] = {
+const plugin_info_t xine_plugin_info[] EXPORTED = {
   /* type, API, "name", version, special_info, init_function */
   { PLUGIN_DEMUX, 26, "rawdv", XINE_VERSION_CODE, &demux_info_raw_dv, init_plugin },
   { PLUGIN_NONE, 0, "", 0, NULL, NULL }
