@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 the xine project
+ * Copyright (C) 2000-2003 the xine project
  *
  * This file is part of xine, a free video player.
  *
@@ -16,12 +16,14 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
- *
+ */
+
+/*
  * RoQ File Demuxer by Mike Melanson (melanson@pcisys.net)
  * For more information regarding the RoQ file format, visit:
  *   http://www.csse.monash.edu.au/~timf/
  *
- * $Id: demux_roq.c,v 1.36 2003/01/19 23:33:33 tmmm Exp $
+ * $Id: demux_roq.c,v 1.54 2007/01/19 00:26:40 dgp85 Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -34,11 +36,18 @@
 #include <string.h>
 #include <stdlib.h>
 
+#define LOG_MODULE "demux_roq"
+#define LOG_VERBOSE
+/*
+#define LOG
+*/
+
 #include "xine_internal.h"
 #include "xineutils.h"
 #include "compat.h"
 #include "demux.h"
 #include "bswap.h"
+#include "group_games.h"
 
 #define RoQ_MAGIC_NUMBER 0x1084
 #define RoQ_CHUNK_PREAMBLE_SIZE 8
@@ -51,61 +60,48 @@
 #define RoQ_SOUND_STEREO   0x1021
 
 typedef struct {
-
   demux_plugin_t       demux_plugin;
 
   xine_stream_t       *stream;
-
-  config_values_t     *config;
-
   fifo_buffer_t       *video_fifo;
   fifo_buffer_t       *audio_fifo;
-
   input_plugin_t      *input;
-
-  off_t                start;
   int                  status;
 
-  unsigned int         fps;
-  unsigned int         frame_pts_inc; 
+  unsigned int         frame_pts_inc;
 
-  unsigned int         width;
-  unsigned int         height;
-  unsigned int         audio_channels;
+  xine_bmiheader       bih;
+  xine_waveformatex    wave;
+
+  int64_t              video_pts_counter;
+  unsigned int         audio_byte_count;
 
-  char                 last_mrl[1024];
 } demux_roq_t ;
 
 typedef struct {
-
   demux_class_t     demux_class;
-
-  /* class-wide, global variables here */
-
-  xine_t           *xine;
-  config_values_t  *config;
 } demux_roq_class_t;
 
 /* returns 1 if the RoQ file was opened successfully, 0 otherwise */
 static int open_roq_file(demux_roq_t *this) {
-
   char preamble[RoQ_CHUNK_PREAMBLE_SIZE];
   int i;
   unsigned int chunk_type;
   unsigned int chunk_size;
+  unsigned int fps;
 
-  this->input->seek(this->input, 0, SEEK_SET);
-  if (this->input->read(this->input, preamble, RoQ_CHUNK_PREAMBLE_SIZE) != 
-    RoQ_CHUNK_PREAMBLE_SIZE)
+  if (this->input->read(this->input, preamble, RoQ_CHUNK_PREAMBLE_SIZE) !=
+      RoQ_CHUNK_PREAMBLE_SIZE)
     return 0;
 
   /* check for the RoQ magic numbers */
   if ((LE_16(&preamble[0]) != RoQ_MAGIC_NUMBER) ||
       (LE_32(&preamble[2]) != 0xFFFFFFFF))
     return 0;
-
-  this->width = this->height = 0;
-  this->audio_channels = 0;  /* assume no audio at first */
+    
+  this->bih.biSize = sizeof(xine_bmiheader);
+  this->bih.biWidth = this->bih.biHeight = 0;
+  this->wave.nChannels = 0;  /* assume no audio at first */
 
   /*
    * RoQ files enjoy a constant framerate; pts calculation:
@@ -116,12 +112,12 @@ static int open_roq_file(demux_roq_t *this) {
    *
    * therefore, the frame pts increment is 90000 / fps
    */
-  this->fps = LE_16(&preamble[6]);
-  this->frame_pts_inc = 90000 / this->fps;
+  fps = LE_16(&preamble[6]);
+  this->frame_pts_inc = 90000 / fps;
 
   /* iterate through the first 2 seconds worth of chunks searching for
    * the RoQ_INFO chunk and an audio chunk */
-  i = this->fps * 2;
+  i = fps * 2;
   while (i-- > 0) {
     /* if this read fails, then maybe it's just a really small RoQ file
      * (even less than 2 seconds) */
@@ -136,11 +132,11 @@ static int open_roq_file(demux_roq_t *this) {
       if (this->input->read(this->input, preamble, 8) != 8)
         break;
 
-      this->width = LE_16(&preamble[0]);
-      this->height = LE_16(&preamble[2]);
+      this->bih.biWidth = LE_16(&preamble[0]);
+      this->bih.biHeight = LE_16(&preamble[2]);
 
       /* if an audio chunk was already found, search is done */
-      if (this->audio_channels)
+      if (this->wave.nChannels)
         break;
 
       /* prep the size for a seek */
@@ -149,12 +145,12 @@ static int open_roq_file(demux_roq_t *this) {
       /* if it was an audio chunk and the info chunk has already been
        * found (as indicated by width and height) then break */
       if (chunk_type == RoQ_SOUND_MONO) {
-        this->audio_channels = 1;
-        if (this->width && this->height)
+        this->wave.nChannels = 1;
+        if (this->bih.biWidth && this->bih.biHeight)
           break;
       } else if (chunk_type == RoQ_SOUND_STEREO) {
-        this->audio_channels = 2;
-        if (this->width && this->height)
+        this->wave.nChannels = 2;
+        if (this->bih.biWidth && this->bih.biHeight)
           break;
       }
     }
@@ -165,25 +161,25 @@ static int open_roq_file(demux_roq_t *this) {
 
   /* after all is said and done, if there is a width and a height,
    * regard it as being a valid file and reset to the first chunk */
-  if (this->width && this->height) {
+  if (this->bih.biWidth && this->bih.biHeight) {
     this->input->seek(this->input, 8, SEEK_SET);
   } else {
     return 0;
   }
 
+  this->video_pts_counter = this->audio_byte_count = 0;
+
   return 1;
 }
 
 static int demux_roq_send_chunk(demux_plugin_t *this_gen) {
-
   demux_roq_t *this = (demux_roq_t *) this_gen;
+
   buf_element_t *buf = NULL;
   char preamble[RoQ_CHUNK_PREAMBLE_SIZE];
   unsigned int chunk_type;
   unsigned int chunk_size;
-  int64_t video_pts_counter = 0;
   int64_t audio_pts;
-  unsigned int audio_byte_count = 0;
   off_t current_file_pos;
 
   /* fetch the next preamble */
@@ -197,28 +193,36 @@ static int demux_roq_send_chunk(demux_plugin_t *this_gen) {
 
   /* if the chunk is an audio chunk, route it to the audio fifo */
   if ((chunk_type == RoQ_SOUND_MONO) || (chunk_type == RoQ_SOUND_STEREO)) {
-    /* rewind over the preamble */
-    this->input->seek(this->input, -RoQ_CHUNK_PREAMBLE_SIZE, SEEK_CUR);
-
-    /* adjust the chunk size */
-    chunk_size += RoQ_CHUNK_PREAMBLE_SIZE;
 
     if( this->audio_fifo ) {
         
       /* do this calculation carefully because I can't trust the
        * 64-bit numerical manipulation */
-      audio_pts = audio_byte_count;
+      audio_pts = this->audio_byte_count;
       audio_pts *= 90000;
-      audio_pts /= (RoQ_AUDIO_SAMPLE_RATE * this->audio_channels);
-      audio_byte_count += chunk_size - 8;  /* do not count the preamble */
+      audio_pts /= (RoQ_AUDIO_SAMPLE_RATE * this->wave.nChannels);
+      this->audio_byte_count += chunk_size - 8;  /* do not count the preamble */
          
       current_file_pos = this->input->get_current_pos(this->input);
 
+      /* send out the preamble */
+      buf = this->audio_fifo->buffer_pool_alloc (this->audio_fifo);
+      buf->type = BUF_AUDIO_ROQ;
+      if( this->input->get_length (this->input) )
+        buf->extra_info->input_normpos = (int)( (double) (current_file_pos - RoQ_CHUNK_PREAMBLE_SIZE) * 
+                                     65535 / this->input->get_length (this->input) );
+      buf->pts = 0;
+      buf->size = RoQ_CHUNK_PREAMBLE_SIZE;
+      memcpy(buf->content, preamble, RoQ_CHUNK_PREAMBLE_SIZE);
+      this->audio_fifo->put(this->audio_fifo, buf);
+
       /* packetize the audio */
       while (chunk_size) {
         buf = this->audio_fifo->buffer_pool_alloc (this->audio_fifo);
         buf->type = BUF_AUDIO_ROQ;
-        buf->extra_info->input_pos = current_file_pos;
+        if( this->input->get_length (this->input) )
+          buf->extra_info->input_normpos = (int)( (double) current_file_pos * 
+                                     65535 / this->input->get_length (this->input) );
         buf->pts = audio_pts;
 
         if (chunk_size > buf->max_size)
@@ -244,36 +248,30 @@ static int demux_roq_send_chunk(demux_plugin_t *this_gen) {
     }
   } else if (chunk_type == RoQ_INFO) {
     /* skip 8 bytes */
-    this->input->seek(this->input, 8, SEEK_CUR);
+    this->input->seek(this->input, chunk_size, SEEK_CUR);
   } else if ((chunk_type == RoQ_QUAD_CODEBOOK) ||
     (chunk_type == RoQ_QUAD_VQ)) {
 
-    current_file_pos = this->input->get_current_pos(this->input) -
-      RoQ_CHUNK_PREAMBLE_SIZE;
+    current_file_pos = this->input->get_current_pos(this->input);
 
-    /* if the chunk is video, check if it is a codebook */
-    if (chunk_type == RoQ_QUAD_CODEBOOK) {
-      /* if it is, figure in the size of the next VQ chunk, too */
-      this->input->seek(this->input, chunk_size, SEEK_CUR);
-      if (this->input->read(this->input, preamble, RoQ_CHUNK_PREAMBLE_SIZE) != 
-        RoQ_CHUNK_PREAMBLE_SIZE) {
-        this->status = DEMUX_FINISHED;
-        return this->status;
-      }
+    /* send out the preamble */
+    buf = this->video_fifo->buffer_pool_alloc (this->video_fifo);
+    buf->type = BUF_VIDEO_ROQ;
+    if( this->input->get_length (this->input) )
+      buf->extra_info->input_normpos = (int)( (double) (current_file_pos - RoQ_CHUNK_PREAMBLE_SIZE) * 
+                                     65535 / this->input->get_length (this->input) );
+    buf->pts = this->video_pts_counter;
+    buf->size = RoQ_CHUNK_PREAMBLE_SIZE;
+    memcpy(buf->content, preamble, RoQ_CHUNK_PREAMBLE_SIZE);
+    this->video_fifo->put(this->video_fifo, buf);
 
-      /* rewind to the start of the codebook chunk */
-      this->input->seek(this->input, current_file_pos, SEEK_SET);
-
-      /* figure out the total video chunk size */
-      chunk_size += (2 * RoQ_CHUNK_PREAMBLE_SIZE) + LE_32(&preamble[2]);
-    }
-
-    /* packetize the video chunk and route it to the video fifo */
     while (chunk_size) {
-      buf = this->video_fifo->buffer_pool_alloc (this->video_fifo);
+      buf = this->video_fifo->buffer_pool_alloc (this->audio_fifo);
       buf->type = BUF_VIDEO_ROQ;
-      buf->extra_info->input_pos = current_file_pos;
-      buf->pts = video_pts_counter;
+      if( this->input->get_length (this->input) )
+        buf->extra_info->input_normpos = (int)( (double) current_file_pos * 
+                                     65535 / this->input->get_length (this->input) );
+      buf->pts = this->video_pts_counter;
 
       if (chunk_size > buf->max_size)
         buf->size = buf->max_size;
@@ -288,20 +286,23 @@ static int demux_roq_send_chunk(demux_plugin_t *this_gen) {
         break;
       }
 
-      if (!chunk_size)
+      /* only indicate end of video frame if this is a VQ chunk */
+      if (!chunk_size && (chunk_type == RoQ_QUAD_VQ))
         buf->decoder_flags |= BUF_FLAG_FRAME_END;
       this->video_fifo->put(this->video_fifo, buf);
     }
-    video_pts_counter += this->frame_pts_inc;
+
+    /* only advance pts counter on VQ frames */
+    if (chunk_type == RoQ_QUAD_VQ)
+      this->video_pts_counter += this->frame_pts_inc;
   } else {
-    printf ("demux_roq: encountered bad chunk type: %d\n", chunk_type);
+    lprintf("encountered bad chunk type: %d\n", chunk_type);
   }
 
   return this->status;
 }
 
 static void demux_roq_send_headers(demux_plugin_t *this_gen) {
-
   demux_roq_t *this = (demux_roq_t *) this_gen;
   buf_element_t *buf;
 
@@ -311,66 +312,70 @@ static void demux_roq_send_headers(demux_plugin_t *this_gen) {
   this->status = DEMUX_OK;
 
   /* load stream information */
-  this->stream->stream_info[XINE_STREAM_INFO_HAS_VIDEO] = 1;
-  this->stream->stream_info[XINE_STREAM_INFO_HAS_AUDIO] = 
-    (this->audio_channels) ? 1 : 0;
-  this->stream->stream_info[XINE_STREAM_INFO_VIDEO_WIDTH] = this->width;
-  this->stream->stream_info[XINE_STREAM_INFO_VIDEO_HEIGHT] = this->height;
-  this->stream->stream_info[XINE_STREAM_INFO_AUDIO_CHANNELS] =
-    this->audio_channels;
-  this->stream->stream_info[XINE_STREAM_INFO_AUDIO_SAMPLERATE] =
-    RoQ_AUDIO_SAMPLE_RATE;
-  this->stream->stream_info[XINE_STREAM_INFO_AUDIO_BITS] = 16;
+  _x_stream_info_set(this->stream, XINE_STREAM_INFO_HAS_VIDEO, 1);
+  _x_stream_info_set(this->stream, XINE_STREAM_INFO_HAS_AUDIO,
+                       (this->wave.nChannels) ? 1 : 0);
+  _x_stream_info_set(this->stream, XINE_STREAM_INFO_VIDEO_WIDTH,
+                       this->bih.biWidth);
+  _x_stream_info_set(this->stream, XINE_STREAM_INFO_VIDEO_HEIGHT,
+                       this->bih.biHeight);
+  _x_stream_info_set(this->stream, XINE_STREAM_INFO_AUDIO_CHANNELS,
+                       this->wave.nChannels);
+  _x_stream_info_set(this->stream, XINE_STREAM_INFO_AUDIO_SAMPLERATE,
+                       RoQ_AUDIO_SAMPLE_RATE);
+  _x_stream_info_set(this->stream, XINE_STREAM_INFO_AUDIO_BITS, 16);
 
   /* send start buffers */
-  xine_demux_control_start(this->stream);
+  _x_demux_control_start(this->stream);
 
   /* send init info to decoders */
   buf = this->video_fifo->buffer_pool_alloc (this->video_fifo);
-  buf->decoder_flags = BUF_FLAG_HEADER;
-  buf->decoder_info[0] = 0;
-  buf->decoder_info[1] = this->frame_pts_inc;  /* initial video_step */
-  /* really be a rebel: No structure at all, just put the video width
-   * and height straight into the buffer, BE_16 format */
-  buf->content[0] = (this->width >> 8) & 0xFF;
-  buf->content[1] = (this->width >> 0) & 0xFF;
-  buf->content[2] = (this->height >> 8) & 0xFF;
-  buf->content[3] = (this->height >> 0) & 0xFF;
-  buf->size = 4;
+  buf->decoder_flags = BUF_FLAG_HEADER|BUF_FLAG_STDHEADER|BUF_FLAG_FRAMERATE|
+                       BUF_FLAG_FRAME_END;
+  buf->decoder_info[0] = this->frame_pts_inc;  /* initial video_step */
+  buf->size = sizeof(xine_bmiheader);
+  memcpy(buf->content, &this->bih, buf->size);
   buf->type = BUF_VIDEO_ROQ;
   this->video_fifo->put (this->video_fifo, buf);
 
-  if (this->audio_fifo && this->audio_channels) {
+  if (this->audio_fifo && this->wave.nChannels) {
+    this->wave.nSamplesPerSec = RoQ_AUDIO_SAMPLE_RATE;
+    this->wave.wBitsPerSample = 16;
+    this->wave.nBlockAlign = (this->wave.wBitsPerSample / 8) * this->wave.nChannels;
+    this->wave.nAvgBytesPerSec = this->wave.nBlockAlign * this->wave.nSamplesPerSec;
+
     buf = this->audio_fifo->buffer_pool_alloc (this->audio_fifo);
     buf->type = BUF_AUDIO_ROQ;
-    buf->decoder_flags = BUF_FLAG_HEADER;
+    buf->decoder_flags = BUF_FLAG_HEADER|BUF_FLAG_STDHEADER|BUF_FLAG_FRAME_END;
     buf->decoder_info[0] = 0;
     buf->decoder_info[1] = RoQ_AUDIO_SAMPLE_RATE;
     buf->decoder_info[2] = 16;
-    buf->decoder_info[3] = this->audio_channels;
+    buf->decoder_info[3] = this->wave.nChannels;
+    buf->size = sizeof(this->wave);
+    memcpy(buf->content, &this->wave, buf->size);
     this->audio_fifo->put (this->audio_fifo, buf);
   }
 }
 
 static int demux_roq_seek (demux_plugin_t *this_gen,
-                             off_t start_pos, int start_time) {
+                             off_t start_pos, int start_time, int playing) {
 
   demux_roq_t *this = (demux_roq_t *) this_gen;
 
   /* if thread is not running, initialize demuxer */
-  if( !this->stream->demux_thread_running ) {
+  if( !playing ) {
 
     /* send new pts */
-    xine_demux_control_newpts(this->stream, 0, 0);
+    _x_demux_control_newpts(this->stream, 0, 0);
 
     this->status = DEMUX_OK;
-  
+
     /* start after the signature chunk */
     this->input->seek(this->input, RoQ_CHUNK_PREAMBLE_SIZE, SEEK_SET);
-    
+
     this->status = DEMUX_OK;
   }
-  
+
   return this->status;
 }
 
@@ -386,7 +391,6 @@ static int demux_roq_get_status (demux_plugin_t *this_gen) {
 }
 
 static int demux_roq_get_stream_length (demux_plugin_t *this_gen) {
-
   return 0;
 }
 
@@ -400,13 +404,12 @@ static int demux_roq_get_optional_data(demux_plugin_t *this_gen,
 }
 
 static demux_plugin_t *open_plugin (demux_class_t *class_gen, xine_stream_t *stream,
-                                    input_plugin_t *input_gen) {
+                                    input_plugin_t *input) {
 
-  input_plugin_t *input = (input_plugin_t *) input_gen;
   demux_roq_t    *this;
 
-  if (! (input->get_capabilities(input) & INPUT_CAP_SEEKABLE)) {
-    printf(_("demux_roq.c: input not seekable, can not handle!\n"));
+  if (!INPUT_IS_SEEKABLE(input)) {
+    xprintf(stream->xine, XINE_VERBOSITY_DEBUG, "input not seekable, can not handle!\n");
     return NULL;
   }
 
@@ -420,16 +423,27 @@ static demux_plugin_t *open_plugin (demux_class_t *class_gen, xine_stream_t *str
   this->demux_plugin.dispose           = demux_roq_dispose;
   this->demux_plugin.get_status        = demux_roq_get_status;
   this->demux_plugin.get_stream_length = demux_roq_get_stream_length;
-  this->demux_plugin.get_video_frame   = NULL;
-  this->demux_plugin.got_video_frame_cb= NULL;
   this->demux_plugin.get_capabilities  = demux_roq_get_capabilities;
   this->demux_plugin.get_optional_data = demux_roq_get_optional_data;
   this->demux_plugin.demux_class       = class_gen;
 
   this->status = DEMUX_FINISHED;
-  
+
   switch (stream->content_detection_method) {
 
+  case METHOD_BY_EXTENSION: {
+    const char *extensions, *mrl;
+
+    mrl = input->get_mrl (input);
+    extensions = class_gen->get_extensions (class_gen);
+
+    if (!_x_demux_check_extension (mrl, extensions)) {
+      free (this);
+      return NULL;
+    }
+  }
+  /* falling through is intended */
+
   case METHOD_BY_CONTENT:
   case METHOD_EXPLICIT:
 
@@ -440,72 +454,40 @@ static demux_plugin_t *open_plugin (demux_class_t *class_gen, xine_stream_t *str
 
   break;
 
-  case METHOD_BY_EXTENSION: {
-    char *ending, *mrl;
-
-    mrl = input->get_mrl (input);
-
-    ending = strrchr(mrl, '.');
-
-    if (!ending) {
-      free (this);
-      return NULL;
-    }
-
-    if (strncasecmp (ending, ".roq", 4)) {
-      free (this);
-      return NULL;
-    }
-
-    if (!open_roq_file(this)) {
-      free (this);
-      return NULL;
-    }
-
-  }
-
-  break;
-
   default:
     free (this);
     return NULL;
   }
 
-  strncpy (this->last_mrl, input->get_mrl (input), 1024);
-
   return &this->demux_plugin;
 }
 
-static char *get_description (demux_class_t *this_gen) {
+static const char *get_description (demux_class_t *this_gen) {
   return "Id RoQ file demux plugin";
 }
 
-static char *get_identifier (demux_class_t *this_gen) {
+static const char *get_identifier (demux_class_t *this_gen) {
   return "RoQ";
 }
 
-static char *get_extensions (demux_class_t *this_gen) {
+static const char *get_extensions (demux_class_t *this_gen) {
   return "roq";
 }
 
-static char *get_mimetypes (demux_class_t *this_gen) {
+static const char *get_mimetypes (demux_class_t *this_gen) {
   return NULL;
 }
 
 static void class_dispose (demux_class_t *this_gen) {
-
   demux_roq_class_t *this = (demux_roq_class_t *) this_gen;
 
   free (this);
 }
 
 void *demux_roq_init_plugin (xine_t *xine, void *data) {
-
   demux_roq_class_t     *this;
 
-  this         = xine_xmalloc (sizeof (demux_roq_class_t));
-  this->config = xine->config;
-  this->xine   = xine;
+  this  = xine_xmalloc (sizeof (demux_roq_class_t));
 
   this->demux_class.open_plugin     = open_plugin;
   this->demux_class.get_description = get_description;
@@ -516,15 +498,3 @@ void *demux_roq_init_plugin (xine_t *xine, void *data) {
 
   return this;
 }
-
-/*
- * exported plugin catalog entry
- */
-
-#if 0
-plugin_info_t xine_plugin_info[] = {
-  /* type, API, "name", version, special_info, init_function */  
-  { PLUGIN_DEMUX, 20, "roq", XINE_VERSION_CODE, NULL, demux_roq_init_plugin },
-  { PLUGIN_NONE, 0, "", 0, NULL, NULL }
-};
-#endif
