@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: input_gnome_vfs.c,v 1.32 2006/09/08 06:20:37 tmattern Exp $
+ * $Id: input_gnome_vfs.c,v 1.34 2007/01/19 01:05:25 dgp85 Exp $
  */
 
 
@@ -204,7 +204,7 @@ gnomevfs_plugin_get_blocksize (input_plugin_t *this_gen)
 	return 32 * 1024;
 }
 
-static char*
+static const char*
 gnomevfs_plugin_get_mrl (input_plugin_t *this_gen)
 {
 	gnomevfs_input_t *this = (gnomevfs_input_t *) this_gen;
@@ -212,7 +212,7 @@ gnomevfs_plugin_get_mrl (input_plugin_t *this_gen)
 	return this->mrl;
 }
 
-static char
+static const char
 *gnomevfs_klass_get_description (input_class_t *this_gen)
 {
 	return _("gnome-vfs input plugin as shipped with xine");
@@ -304,7 +304,7 @@ gnomevfs_klass_dispose (input_class_t *this_gen)
 	g_free (this);
 }
 
-static char * ignore_scheme[] = { "cdda", "file", "http" };
+static const char *const ignore_scheme[] = { "cdda", "file", "http" };
 
 static input_plugin_t *
 gnomevfs_klass_get_instance (input_class_t *klass_gen, xine_stream_t *stream,
