@@ -517,11 +517,9 @@ static int extract_mrl(v4l_input_plugin_t *this, char *mrl)
     
     /* Get frequency, if available */  
     sscanf(locator, "/%d", &frequency);
-    lprintf("Tuner name: '%s' freq: %d\n", tuner_name, frequency);
-  } else {
-    xprintf(this->stream->xine, XINE_VERBOSITY_LOG, 
-            "input_v4l: No tuner name given. Expected syntax: v4l:/tuner/frequency\n" 
-            "input_v4l: Using currently tuned settings\n");
+    
+    /* cannot use xprintf to log in this routine */
+    lprintf("input_v4l: Tuner name: %s frequency %d\n", tuner_name, frequency );
   }
   
   this->frequency  = frequency;
@@ -1628,7 +1626,7 @@ static void v4l_plugin_dispose (input_plugin_t *this_gen) {
  *
  * Get the current MRL used by the plugin.
  */
-static char* v4l_plugin_get_mrl (input_plugin_t *this_gen) {
+static const char* v4l_plugin_get_mrl (input_plugin_t *this_gen) {
   v4l_input_plugin_t *this = (v4l_input_plugin_t *) this_gen;
   
   return this->mrl;
@@ -1907,8 +1905,8 @@ static void *init_video_class (xine_t *xine, void *data)
   this->input_class.dispose            = v4l_class_dispose;
   this->input_class.eject_media        = NULL;
   
-  config->register_string (config, "media.video4linux.video_device",
-			   VIDEO_DEV,
+  config->register_filename (config, "media.video4linux.video_device",
+			   VIDEO_DEV, XINE_CONFIG_STRING_IS_DEVICE_NAME,
 			   _("v4l video device"),
 			   _("The path to your Video4Linux video device."),
 			   10, NULL, NULL);
@@ -1933,8 +1931,8 @@ static void *init_radio_class (xine_t *xine, void *data)
   this->input_class.dispose            = v4l_class_dispose;
   this->input_class.eject_media        = NULL;
   
-  config->register_string (config, "media.video4linux.radio_device",
-			   RADIO_DEV,
+  config->register_filename (config, "media.video4linux.radio_device",
+			   RADIO_DEV, XINE_CONFIG_STRING_IS_DEVICE_NAME,
 			   _("v4l radio device"),
 			   _("The path to your Video4Linux radio device."),
 			   10, NULL, NULL);
