@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2001-2004 Billy Biggs <vektor@dumbterm.net>,
- *                         Hkan Hjort <d95hjort@dtek.chalmers.se>,
- *                         Bjrn Englund <d4bjorn@dtek.chalmers.se>
+ *                         Håkan Hjort <d95hjort@dtek.chalmers.se>,
+ *                         Björn Englund <d4bjorn@dtek.chalmers.se>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -603,10 +603,12 @@ static int findDirFile( const char *path, const char *file, char *filename )
             sprintf( filename, "%s%s%s", path,
                      ( ( path[ strlen( path ) - 1 ] == '/' ) ? "" : "/" ),
                      ent->d_name );
+            closedir (dir);
             return 0;
         }
     }
 
+    closedir (dir);
     return -1;
 }
 
