@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 the xine project
+ * Copyright (C) 2000-2003 the xine project
  *
  * This file is part of xine, a free video player.
  *
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: rtsp_session.h,v 1.3 2002/12/24 01:10:53 holstsn Exp $
+ * $Id: rtsp_session.h,v 1.7 2006/12/18 21:31:47 klan Exp $
  *
  * high level interface to rtsp servers.
  */
@@ -27,11 +27,13 @@
 
 typedef struct rtsp_session_s rtsp_session_t;
 
-rtsp_session_t *rtsp_session_start(char *mrl);
+rtsp_session_t *rtsp_session_start(xine_stream_t *stream, char *mrl);
+
+void rtsp_session_set_start_time(rtsp_session_t *this, int start_time);
 
 int rtsp_session_read(rtsp_session_t *session, char *data, int len);
 
-int rtsp_session_peek_header(rtsp_session_t *this, char *buf);
+int rtsp_session_peek_header(rtsp_session_t *this, char *buf, int maxsize);
 
 void rtsp_session_end(rtsp_session_t *session);
 
