@@ -2048,11 +2048,11 @@ static uint16_t extension_payload(bitfile *ld, drc_info *drc, uint16_t count)
         return n;
     case EXT_FILL_DATA:
         /* fill_nibble = */ faad_getbits(ld, 4
-            DEBUGVAR(1,136,"extension_payload(): fill_nibble")); /* must be 0000 */
+            DEBUGVAR(1,136,"extension_payload(): fill_nibble")); /* must be '0000' */
         for (i = 0; i < count-1; i++)
         {
             /* fill_byte[i] = */ faad_getbits(ld, 8
-                DEBUGVAR(1,88,"extension_payload(): fill_byte")); /* must be 10100101 */
+                DEBUGVAR(1,88,"extension_payload(): fill_byte")); /* must be '10100101' */
         }
         return count;
     case EXT_DATA_ELEMENT:
