@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2000-2003 the xine project
+ * Copyright (C) 2000-2006 the xine project
  * 
  * This file is part of xine, a free video player.
  * 
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: w32codec.c,v 1.145.2.2 2005/07/17 21:50:04 miguelfreitas Exp $
+ * $Id: w32codec.c,v 1.155 2006/07/10 22:08:43 dgp85 Exp $
  *
  * routines for using w32 codecs
  * DirectShow support by Miguel Freitas (Nov/2001)
@@ -59,6 +59,8 @@
 #include "buffer.h"
 #include "xineutils.h"
 
+#include "common.c"
+
 static GUID CLSID_Voxware =
 {
      0x73f7a062, 0x8829, 0x11d1,
@@ -856,7 +858,7 @@ static void w32v_decode_data (video_decoder_t *this_gen, buf_element_t *buf) {
       vo_frame_t *img;
       uint8_t    *img_buffer = this->img_buffer;
 
-      Check_FS_Segment();
+      Check_FS_Segment(this->ldt_fs);
 
       /* decoder video frame */
 
@@ -1181,7 +1183,7 @@ static int w32a_init_audio (w32a_decoder_t *this,
 
   this->output_open = this->stream->audio_out->open( this->stream->audio_out, this->stream,
 					      16, in_fmt->nSamplesPerSec, 
-					      (in_fmt->nChannels >= 2) ? AO_CAP_MODE_STEREO : AO_CAP_MODE_MONO);
+					      _x_ao_channels2mode(in_fmt->nChannels));
   if (!this->output_open) {
     xprintf(this->stream->xine, XINE_VERBOSITY_DEBUG,
 	    "w32codec: (ACM_Decoder) Cannot open audio output device\n");
@@ -1273,18 +1275,18 @@ static int w32a_init_audio (w32a_decoder_t *this,
   xprintf(this->stream->xine, XINE_VERBOSITY_DEBUG,
 	  "w32codec: Recommended source buffer size: %d\n", this->rec_audio_src_size); 
 
-  if( this->buf )
-    free(this->buf);
-  
-  if( this->outbuf )
-    free(this->outbuf);
-
   if( this->rec_audio_src_size < in_fmt->nBlockAlign ) {
     this->rec_audio_src_size = in_fmt->nBlockAlign;
     xprintf(this->stream->xine, XINE_VERBOSITY_DEBUG,
 	    "w32codec: adjusting source buffer size to %d\n", this->rec_audio_src_size); 
   }
   
+  if( this->buf )
+    free(this->buf);
+  
+  if( this->outbuf )
+    free(this->outbuf);
+
   this->max_audio_src_size = 2 * this->rec_audio_src_size;
   
   this->buf = malloc( this->max_audio_src_size );
@@ -1494,7 +1496,7 @@ static void w32a_decode_data (audio_decoder_t *this_gen, buf_element_t *buf) {
     if( (int)buf->size <= 0 )
       return;
 
-    Check_FS_Segment();
+    Check_FS_Segment(this->ldt_fs);
     
     w32a_decode_audio (this, buf->content, buf->size,
 		       buf->decoder_flags & BUF_FLAG_FRAME_END, 
@@ -1592,15 +1594,7 @@ static void *init_video_decoder_class (xine_t *xine, void *data) {
   config_values_t *cfg;
 
   cfg = xine->config;
-  win32_def_path = cfg->register_string (cfg, "decoder.external.win32_codecs_path", WIN32_PATH,
-					 _("path to Win32 codecs"),
-					 _("If you have the Windows or Apple Quicktime codec packs "
-					   "installed, specify the path the codec directory here. "
-					   "If xine can find the Windows or Apple Quicktime codecs, "
-					   "it will use them to decode various Windows Media and "
-					   "Quicktime streams for you. Consult the xine FAQ for "
-					   "more information on how to install the codecs."),
-					 10, NULL, NULL);
+  if ((win32_def_path = get_win32_codecs_path(cfg)) == NULL) return NULL;
 
   this = (w32v_class_t *) xine_xmalloc (sizeof (w32v_class_t));
 
@@ -1661,6 +1655,9 @@ static void *init_audio_decoder_class (xine_t *xine, void *data) {
   w32a_class_t    *this;
   config_values_t *cfg;
   
+  cfg = xine->config;
+  if ((win32_def_path = get_win32_codecs_path(cfg)) == NULL) return NULL;
+
   this = (w32a_class_t *) xine_xmalloc (sizeof (w32a_class_t));
 
   this->decoder_class.open_plugin     = open_audio_decoder_plugin;
@@ -1668,17 +1665,6 @@ static void *init_audio_decoder_class (xine_t *xine, void *data) {
   this->decoder_class.get_description = get_description;
   this->decoder_class.dispose         = dispose_class;
 
-  cfg = xine->config;
-  win32_def_path = cfg->register_string (cfg, "decoder.external.win32_codecs_path", WIN32_PATH,
-					 _("path to Win32 codecs"),
-					 _("If you have the Windows or Apple Quicktime codec packs "
-					   "installed, specify the path the codec directory here. "
-					   "If xine can find the Windows or Apple Quicktime codecs, "
-					   "it will use them to decode various Windows Media and "
-					   "Quicktime streams for you. Consult the xine FAQ for "
-					   "more information on how to install the codecs."),
-					 10, NULL, NULL);
-
   pthread_once (&once_control, init_routine);
 
   return this;
@@ -1700,7 +1686,7 @@ static uint32_t video_types[] = {
   0
  };
 
-static decoder_info_t dec_info_video = {
+static const decoder_info_t dec_info_video = {
   video_types,         /* supported types */
   1                    /* priority        */
 };
@@ -1713,12 +1699,12 @@ static uint32_t audio_types[] = {
   0
  };
 
-static decoder_info_t dec_info_audio = {
+static const decoder_info_t dec_info_audio = {
   audio_types,         /* supported types */
   1                    /* priority        */
 };
 
-plugin_info_t xine_plugin_info[] = {
+const plugin_info_t xine_plugin_info[] EXPORTED = {
   /* type, API, "name", version, special_info, init_function */  
   { PLUGIN_VIDEO_DECODER | PLUGIN_MUST_PRELOAD, 18, "win32v", XINE_VERSION_CODE, &dec_info_video, init_video_decoder_class },
   { PLUGIN_AUDIO_DECODER | PLUGIN_MUST_PRELOAD, 15, "win32a", XINE_VERSION_CODE, &dec_info_audio, init_audio_decoder_class },
