@@ -23,7 +23,7 @@
  * process. It simply paints the screen a solid color and rotates through
  * colors on each iteration.
  *
- * $Id: fooviz.c,v 1.26 2006/06/02 22:18:58 dsalt Exp $
+ * $Id: fooviz.c,v 1.28 2006/12/02 22:35:18 miguelfreitas Exp $
  *
  */
 
@@ -118,6 +118,7 @@ static int fooviz_port_open(xine_audio_port_t *port_gen, xine_stream_t *stream,
   this->channels = _x_ao_mode2channels(mode);
   this->samples_per_frame = rate / FPS;
   this->data_idx = 0;
+  this->sample_counter = 0;
 
   this->vo_port->open(this->vo_port, XINE_ANON_STREAM);
   this->metronom->set_master(this->metronom, stream->metronom);
@@ -180,7 +181,7 @@ static void fooviz_port_put_buffer (xine_audio_port_t *port_gen,
       data8 += samples_used * this->channels;
   
       /* scale 8 bit data to 16 bits and convert to signed as well */
-      for( i = 0; i < buf->num_frames && this->data_idx < NUMSAMPLES;
+      for( i = samples_used; i < buf->num_frames && this->data_idx < NUMSAMPLES;
            i++, this->data_idx++, data8 += this->channels ) {
         this->data[0][this->data_idx] = ((int16_t)data8[0] << 8) - 0x8000;
         this->data[1][this->data_idx] = ((int16_t)data8[j] << 8) - 0x8000;
@@ -189,24 +190,31 @@ static void fooviz_port_put_buffer (xine_audio_port_t *port_gen,
       data = buf->mem;
       data += samples_used * this->channels;
   
-      for( i = 0; i < buf->num_frames && this->data_idx < NUMSAMPLES;
+      for( i = samples_used; i < buf->num_frames && this->data_idx < NUMSAMPLES;
            i++, this->data_idx++, data += this->channels ) {
         this->data[0][this->data_idx] = data[0];
         this->data[1][this->data_idx] = data[j];
       }
     }
   
-    if( this->sample_counter >= this->samples_per_frame &&
-        this->data_idx == NUMSAMPLES ) {
+    if( this->sample_counter >= this->samples_per_frame ) {
   
-      this->data_idx = 0;
       samples_used += this->samples_per_frame;
   
       frame = this->vo_port->get_frame (this->vo_port, FOO_WIDTH, FOO_HEIGHT,
                                         this->ratio, XINE_IMGFMT_YUY2,
                                         VO_BOTH_FIELDS);
       frame->extra_info->invalid = 1;
-      frame->bad_frame = 0;
+      
+      /* frame is marked as bad if we don't have enough samples for 
+       * updating the viz plugin (calculations may be skipped).
+       * we must keep the framerate though. */
+      if( this->data_idx == NUMSAMPLES ) {
+        frame->bad_frame = 0;
+        this->data_idx = 0;
+      } else {
+        frame->bad_frame = 1;
+      }
       frame->duration = 90000 * this->samples_per_frame / port->rate;
       frame->pts = pts;
       this->metronom->got_video_frame(this->metronom, frame);
@@ -315,7 +323,7 @@ static void *fooviz_init_plugin(xine_t *xine, void *data)
 /* plugin catalog information */
 static const post_info_t fooviz_special_info = { XINE_POST_TYPE_AUDIO_VISUALIZATION };
 
-const plugin_info_t xine_plugin_info[] = {
+const plugin_info_t xine_plugin_info[] EXPORTED = {
   /* type, API, "name", version, special_info, init_function */  
   { PLUGIN_POST, 9, "fooviz", XINE_VERSION_CODE, &fooviz_special_info, &fooviz_init_plugin },
   { PLUGIN_NONE, 0, "", 0, NULL, NULL }
