@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  *
- * $Id: video_out_pgx32.c,v 1.16 2006/06/02 22:18:58 dsalt Exp $
+ * $Id: video_out_pgx32.c,v 1.17 2006/07/10 22:08:44 dgp85 Exp $
  *
  * video_out_pgx32.c, Sun PGX32 output plugin for xine
  *
@@ -890,7 +890,7 @@ static void *pgx32_init_class(xine_t *xine, void *visual_gen)
   return class;
 }
 
-const plugin_info_t xine_plugin_info[] = {
+const plugin_info_t xine_plugin_info[] EXPORTED = {
   {PLUGIN_VIDEO_OUT, 21, "pgx32", XINE_VERSION_CODE, &vo_info_pgx32, pgx32_init_class},
   {PLUGIN_NONE, 0, "", 0, NULL, NULL}
 };
