@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  *
- * $Id: video_out_pgx64.c,v 1.72 2004/12/12 22:01:27 mroi Exp $
+ * $Id: video_out_pgx64.c,v 1.78 2006/07/10 22:08:44 dgp85 Exp $
  *
  * video_out_pgx64.c, Sun XVR100/PGX64/PGX24 output plugin for xine
  *
@@ -47,7 +47,6 @@
 #include <dga/dga.h>
 
 #include "xine_internal.h"
-#include "alphablend.h"
 #include "bswap.h"
 #include "vo_scale.h"
 #include "xineutils.h"
@@ -912,6 +911,9 @@ static void pgx64_overlay_begin(vo_driver_t *this_gen, vo_frame_t *frame_gen, in
   pgx64_driver_t *this = (pgx64_driver_t *)(void *)this_gen;
   /*pgx64_frame_t *frame = (pgx64_frame_t *)frame_gen;*/
 
+  this->alphablend_extra_data.offset_x = frame_gen->overlay_offset_x;
+  this->alphablend_extra_data.offset_y = frame_gen->overlay_offset_y;
+
   if ((this->chromakey_en) && (changed || this->chromakey_regen_needed)) {
     pgx64_overlay_t *ovl, *next_ovl;
 
@@ -982,16 +984,16 @@ static void pgx64_overlay_key_blend(vo_driver_t *this_gen, vo_frame_t *frame_gen
         len = 0;
       }
 
-      if ((y >= overlay->clip_top) && (y <= overlay->clip_bottom) && (x <= overlay->clip_right)) {
-        if ((x < overlay->clip_left) && (x + width - 1 >= overlay->clip_left)) {
-          width -= overlay->clip_left - x;
-          len += overlay->clip_left - x;
+      if ((y >= overlay->hili_top) && (y <= overlay->hili_bottom) && (x <= overlay->hili_right)) {
+        if ((x < overlay->hili_left) && (x + width - 1 >= overlay->hili_left)) {
+          width -= overlay->hili_left - x;
+          len += overlay->hili_left - x;
         }
-        else if (x > overlay->clip_left)  {
+        else if (x > overlay->hili_left)  {
           use_clip_palette = 1;
-          if (x + width - 1 > overlay->clip_right) {
-            width -= overlay->clip_right - x;
-            len += overlay->clip_right - x;
+          if (x + width - 1 > overlay->hili_right) {
+            width -= overlay->hili_right - x;
+            len += overlay->hili_right - x;
           } 
         }
       }
@@ -1002,8 +1004,8 @@ static void pgx64_overlay_key_blend(vo_driver_t *this_gen, vo_frame_t *frame_gen
         uint8_t *src_trans;
           
         if (use_clip_palette) {
-          src_clut = (clut_t *)&overlay->clip_color;
-          src_trans = (uint8_t *)&overlay->clip_trans;
+          src_clut = (clut_t *)&overlay->hili_color;
+          src_trans = (uint8_t *)&overlay->hili_trans;
         }
         else {
           src_clut = (clut_t *)&overlay->color;
@@ -1082,12 +1084,12 @@ static void pgx64_overlay_blend(vo_driver_t *this_gen, vo_frame_t *frame_gen, vo
         /* FIXME: Implement out of place alphablending functions for better performance */
         switch (frame->format) {
           case XINE_IMGFMT_YV12: {
-            blend_yuv(frame->buffer_ptrs, overlay, frame->width, frame->height, frame->vo_frame.pitches, &this->alphablend_extra_data);
+            _x_blend_yuv(frame->buffer_ptrs, overlay, frame->width, frame->height, frame->vo_frame.pitches, &this->alphablend_extra_data);
           }
           break;
 
           case XINE_IMGFMT_YUY2: {
-            blend_yuy2(frame->buffer_ptrs[0], overlay, frame->width, frame->height, frame->vo_frame.pitches[0], &this->alphablend_extra_data);
+            _x_blend_yuy2(frame->buffer_ptrs[0], overlay, frame->width, frame->height, frame->vo_frame.pitches[0], &this->alphablend_extra_data);
           }
           break;
         }
@@ -1095,12 +1097,12 @@ static void pgx64_overlay_blend(vo_driver_t *this_gen, vo_frame_t *frame_gen, vo
       else {
         switch (frame->format) {
           case XINE_IMGFMT_YV12: {
-            blend_yuv(frame->vo_frame.base, overlay, frame->width, frame->height, frame->vo_frame.pitches, &this->alphablend_extra_data);
+            _x_blend_yuv(frame->vo_frame.base, overlay, frame->width, frame->height, frame->vo_frame.pitches, &this->alphablend_extra_data);
           }
           break;
 
           case XINE_IMGFMT_YUY2: {
-            blend_yuy2(frame->vo_frame.base[0], overlay, frame->width, frame->height, frame->vo_frame.pitches[0], &this->alphablend_extra_data);
+            _x_blend_yuy2(frame->vo_frame.base[0], overlay, frame->width, frame->height, frame->vo_frame.pitches[0], &this->alphablend_extra_data);
           }
           break;
         }
@@ -1322,13 +1324,7 @@ static void pgx64_config_changed(void *user_data, xine_cfg_entry_t *entry)
     pgx64_set_property(this_gen, VO_PROP_COLORKEY, entry->num_value);
     update_colour_key_rgb(this);
   } 
-  else if (strcmp(entry->key, "video.output.pgx64_brightness") == 0) {
-    pgx64_set_property(this_gen, VO_PROP_BRIGHTNESS, entry->num_value);
-  }
-  else if (strcmp(entry->key, "video.output.pgx64_saturation") == 0) {
-    pgx64_set_property(this_gen, VO_PROP_SATURATION, entry->num_value);
-  }
-  else if (strcmp(entry->key, "") == 0) {
+  else if (strcmp(entry->key, "video.device.pgx64_chromakey_en") == 0) {
     this->chromakey_en = entry->num_value;
   }
   else if (strcmp(entry->key, "video.device.pgx64_multibuf_en") == 0) {
@@ -1347,7 +1343,7 @@ static void pgx64_dispose_class(video_driver_class_t *class_gen)
   free(class);
 }
 
-static vo_info_t vo_info_pgx64 = {
+static const vo_info_t vo_info_pgx64 = {
   10,
   XINE_VISUAL_TYPE_X11
 };
@@ -1470,14 +1466,8 @@ static vo_driver_t *pgx64_init_driver(video_driver_class_t *class_gen, const voi
       "Try using different values if you see the video showing through other windows."),
     20, pgx64_config_changed, this);
   update_colour_key_rgb(this);
-  this->brightness  = class->config->register_range(this->class->config, "video.output.pgx64_brightness", 0, -64, 63,
-    _("video brightness"),
-    _("The brightness of the video image."),
-    10, pgx64_config_changed, this);
-  this->saturation  = class->config->register_range(this->class->config, "video.output.pgx64_saturation", 16, 0, 31,
-    _("video saturation"),
-    _("The saturation of the video image."),
-    10, pgx64_config_changed, this);
+  this->brightness  = 0;
+  this->saturation  = 16;
   this->chromakey_en = class->config->register_bool(this->class->config, "video.device.pgx64_chromakey_en", 0,
     _("enable chroma keying"),
     _("Draw OSD graphics on top of the overlay colour key rather than blend them into each frame."),
@@ -1524,7 +1514,7 @@ static void *pgx64_init_class(xine_t *xine, void *visual_gen)
   return class;
 }
 
-plugin_info_t xine_plugin_info[] = {
-  {PLUGIN_VIDEO_OUT, 20, "pgx64", XINE_VERSION_CODE, &vo_info_pgx64, pgx64_init_class},
+const plugin_info_t xine_plugin_info[] EXPORTED = {
+  {PLUGIN_VIDEO_OUT, 21, "pgx64", XINE_VERSION_CODE, &vo_info_pgx64, pgx64_init_class},
   {PLUGIN_NONE, 0, "", 0, NULL, NULL}
 };
