@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: video_out_sdl.c,v 1.42 2004/12/12 22:01:28 mroi Exp $
+ * $Id: video_out_sdl.c,v 1.48 2006/07/10 22:08:44 dgp85 Exp $
  *
  * video_out_sdl.c, Simple DirectMedia Layer
  *
@@ -47,7 +47,8 @@
 #include <string.h>
 #include <inttypes.h>
 #include <math.h>
-#if defined (__FreeBSD__)
+
+#ifdef HAVE_SDL11_SDL_H
 # include <SDL11/SDL.h>
 #else
 # include <SDL.h>
@@ -62,7 +63,6 @@
 #include "xine.h"
 #include "xine_internal.h"
 #include "video_out.h"
-#include "alphablend.h"
 #include "xineutils.h"
 #include "vo_scale.h"
 
@@ -242,11 +242,14 @@ static void sdl_overlay_blend (vo_driver_t *this_gen, vo_frame_t *frame_gen, vo_
   sdl_driver_t  *this = (sdl_driver_t *) this_gen;
   sdl_frame_t   *frame = (sdl_frame_t *) frame_gen;
 
+  this->alphablend_extra_data.offset_x = frame_gen->overlay_offset_x;
+  this->alphablend_extra_data.offset_y = frame_gen->overlay_offset_y;
+  
   if (overlay->rle) {
     if( frame->format == XINE_IMGFMT_YV12 )
-      blend_yuv( frame->vo_frame.base, overlay, frame->width, frame->height, frame->vo_frame.pitches, &this->alphablend_extra_data);
+      _x_blend_yuv( frame->vo_frame.base, overlay, frame->width, frame->height, frame->vo_frame.pitches, &this->alphablend_extra_data);
     else
-      blend_yuy2( frame->vo_frame.base[0], overlay, frame->width, frame->height, frame->vo_frame.pitches[0], &this->alphablend_extra_data);
+      _x_blend_yuy2( frame->vo_frame.base[0], overlay, frame->width, frame->height, frame->vo_frame.pitches[0], &this->alphablend_extra_data);
   }
 
 }
@@ -600,13 +603,13 @@ static void *init_class (xine_t *xine, void *visual_gen) {
   return this;
 }
 
-static vo_info_t vo_info_sdl = {
+static const vo_info_t vo_info_sdl = {
   4,                    /* priority */
   XINE_VISUAL_TYPE_X11, /* visual type supported by this plugin */
 };
 
-plugin_info_t xine_plugin_info[] = {
+const plugin_info_t xine_plugin_info[] EXPORTED = {
   /* type, API, "name", version, special_info, init_function */
-  { PLUGIN_VIDEO_OUT, 20, "sdl", XINE_VERSION_CODE, &vo_info_sdl, init_class },
+  { PLUGIN_VIDEO_OUT, 21, "sdl", XINE_VERSION_CODE, &vo_info_sdl, init_class },
   { PLUGIN_NONE, 0, "" , 0 , NULL, NULL}
 };
