@@ -24,7 +24,7 @@
 
 #include "config.h"
 
-#ifdef ARCH_X86
+#if defined(ARCH_X86) || defined(ARCH_X86_64)
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -47,42 +47,77 @@ do {				\
 	movq_r2m (src, dest);	\
 } while (0)
 
-static mmx_t mmx_subYw = {0x1010101010101010};
-static mmx_t mmx_addYw = {0x0000000000000000};
+typedef struct mmx_csc_s mmx_csc_t;
 
-void mmx_yuv2rgb_set_gamma(int gamma) 
+struct mmx_csc_s {
+  mmx_t subYw;
+  mmx_t addYw;
+  mmx_t U_green;
+  mmx_t U_blue;
+  mmx_t V_red;
+  mmx_t V_green;
+  mmx_t Y_coeff;
+};
+
+extern const int32_t Inverse_Table_6_9[8][4];
+
+void mmx_yuv2rgb_set_csc_levels(yuv2rgb_factory_t *this,
+				int brightness, int contrast, int saturation)
 {
-int a,s,i;
+  int a,s,i;
+  int crv, cbu, cgu, cgv, cty;
+  mmx_csc_t *csc;
 
-  if( gamma <= 16 ) {
+  /* 'table_mmx' is 64bit aligned for better performance */
+  if (this->table_mmx == NULL) {
+    this->table_mmx = xine_xmalloc_aligned (8, sizeof(mmx_csc_t), &this->table_mmx_base);
+  }
+
+  if( brightness <= 16 ) {
     a = 0;
-    s = 16 - gamma;
+    s = 16 - brightness;
   } else {
-    a = gamma - 16;
+    a = brightness - 16;
     s = 0;
   }
-  
+
+  csc = (mmx_csc_t *) this->table_mmx;
+
   for( i = 0; i < 8; i++ ) {
-    *((unsigned char *)&mmx_subYw + i) = s;
-    *((unsigned char *)&mmx_addYw + i) = a;
+    csc->subYw.ub[i] = s;
+    csc->addYw.ub[i] = a;
+  }
+
+  crv = Inverse_Table_6_9[this->matrix_coefficients][0];
+  crv = (crv * saturation + 512) / 1024;
+  cbu = Inverse_Table_6_9[this->matrix_coefficients][1];
+  cbu = (cbu * saturation + 512) / 1024;
+  cbu = (cbu > 32767) ? 32767 : cbu;
+  cgu = Inverse_Table_6_9[this->matrix_coefficients][2];
+  cgu = (cgu * saturation + 512) / 1024;
+  cgv = Inverse_Table_6_9[this->matrix_coefficients][3];
+  cgv = (cgv * saturation + 512) / 1024;
+  cty = (76309 * contrast + 512) / 1024;
+
+  for (i=0; i < 4; i++) {
+    csc->U_green.w[i] = -cgu;
+    csc->U_blue.w[i]  =  cbu;
+    csc->V_red.w[i]   =  crv;
+    csc->V_green.w[i] = -cgv;
+    csc->Y_coeff.w[i] =  cty;
   }
 }
 
-static inline void mmx_yuv2rgb (uint8_t * py, uint8_t * pu, uint8_t * pv)
+static inline void mmx_yuv2rgb (uint8_t * py, uint8_t * pu, uint8_t * pv, mmx_csc_t *csc)
 {
-    static mmx_t mmx_80w = {0x0080008000800080};
-    static mmx_t mmx_U_green = {0xf37df37df37df37d};
-    static mmx_t mmx_U_blue = {0x4093409340934093};
-    static mmx_t mmx_V_red = {0x3312331233123312};
-    static mmx_t mmx_V_green = {0xe5fce5fce5fce5fc};
-    static mmx_t mmx_00ffw = {0x00ff00ff00ff00ff};
-    static mmx_t mmx_Y_coeff = {0x253f253f253f253f};
+    static mmx_t mmx_80w = {0x0080008000800080ULL};
+    static mmx_t mmx_00ffw = {0x00ff00ff00ff00ffULL};
 
     movq_m2r (*py, mm6);		// mm6 = Y7 Y6 Y5 Y4 Y3 Y2 Y1 Y0
     pxor_r2r (mm4, mm4);		// mm4 = 0
 
-    psubusb_m2r (mmx_subYw, mm6);	// Y -= 16
-    paddusb_m2r (mmx_addYw, mm6);
+    psubusb_m2r (csc->subYw, mm6);	// Y -= 16
+    paddusb_m2r (csc->addYw, mm6);
 
     movd_m2r (*pu, mm0);		// mm0 = 00 00 00 00 u3 u2 u1 u0
     movq_r2r (mm6, mm7);		// mm7 = Y7 Y6 Y5 Y4 Y3 Y2 Y1 Y0
@@ -93,7 +128,7 @@ static inline void mmx_yuv2rgb (uint8_t * py, uint8_t * pu, uint8_t * pv)
     movd_m2r (*pv, mm1);		// mm1 = 00 00 00 00 v3 v2 v1 v0
     psllw_i2r (3, mm6);			// promote precision
 
-    pmulhw_m2r (mmx_Y_coeff, mm6);	// mm6 = luma_rgb even
+    pmulhw_m2r (csc->Y_coeff, mm6);	// mm6 = luma_rgb even
     psllw_i2r (3, mm7);			// promote precision
 
     punpcklbw_r2r (mm4, mm0);		// mm0 = u3 u2 u1 u0
@@ -101,7 +136,7 @@ static inline void mmx_yuv2rgb (uint8_t * py, uint8_t * pu, uint8_t * pv)
     psubsw_m2r (mmx_80w, mm0);		// u -= 128
     punpcklbw_r2r (mm4, mm1);		// mm1 = v3 v2 v1 v0
 
-    pmulhw_m2r (mmx_Y_coeff, mm7);	// mm7 = luma_rgb odd
+    pmulhw_m2r (csc->Y_coeff, mm7);	// mm7 = luma_rgb odd
     psllw_i2r (3, mm0);			// promote precision
 
     psubsw_m2r (mmx_80w, mm1);		// v -= 128
@@ -111,7 +146,7 @@ static inline void mmx_yuv2rgb (uint8_t * py, uint8_t * pu, uint8_t * pv)
 
     movq_r2r (mm1, mm4);		// mm4 = v3 v2 v1 v0
 
-    pmulhw_m2r (mmx_U_blue, mm0);	// mm0 = chroma_b
+    pmulhw_m2r (csc->U_blue, mm0);		// mm0 = chroma_b
 
 
     // slot
@@ -120,7 +155,7 @@ static inline void mmx_yuv2rgb (uint8_t * py, uint8_t * pu, uint8_t * pv)
     // slot
 
 
-    pmulhw_m2r (mmx_V_red, mm1);	// mm1 = chroma_r
+    pmulhw_m2r (csc->V_red, mm1);	// mm1 = chroma_r
     movq_r2r (mm0, mm3);		// mm3 = chroma_b
 
     paddsw_r2r (mm6, mm0);		// mm0 = B6 B4 B2 B0
@@ -129,7 +164,7 @@ static inline void mmx_yuv2rgb (uint8_t * py, uint8_t * pu, uint8_t * pv)
     packuswb_r2r (mm0, mm0);		// saturate to 0-255
 
 
-    pmulhw_m2r (mmx_U_green, mm2);	// mm2 = u * u_green
+    pmulhw_m2r (csc->U_green, mm2);	// mm2 = u * u_green
 
 
     packuswb_r2r (mm3, mm3);		// saturate to 0-255
@@ -138,7 +173,7 @@ static inline void mmx_yuv2rgb (uint8_t * py, uint8_t * pu, uint8_t * pv)
     punpcklbw_r2r (mm3, mm0);		// mm0 = B7 B6 B5 B4 B3 B2 B1 B0
 
 
-    pmulhw_m2r (mmx_V_green, mm4);	// mm4 = v * v_green
+    pmulhw_m2r (csc->V_green, mm4);	// mm4 = v * v_green
 
     
     // slot
@@ -177,9 +212,9 @@ static inline void mmx_yuv2rgb (uint8_t * py, uint8_t * pu, uint8_t * pv)
 // basic opt
 static inline void mmx_unpack_16rgb (uint8_t * image, int cpu)
 {
-    static mmx_t mmx_bluemask = {0xf8f8f8f8f8f8f8f8};
-    static mmx_t mmx_greenmask = {0xfcfcfcfcfcfcfcfc};
-    static mmx_t mmx_redmask = {0xf8f8f8f8f8f8f8f8};
+    static mmx_t mmx_bluemask = {0xf8f8f8f8f8f8f8f8ULL};
+    static mmx_t mmx_greenmask = {0xfcfcfcfcfcfcfcfcULL};
+    static mmx_t mmx_redmask = {0xf8f8f8f8f8f8f8f8ULL};
 
     /*
      * convert RGB plane to RGB 16 bits
@@ -222,9 +257,9 @@ static inline void mmx_unpack_16rgb (uint8_t * image, int cpu)
 
 static inline void mmx_unpack_15rgb (uint8_t * image, int cpu)
 {
-    static mmx_t mmx_bluemask = {0xf8f8f8f8f8f8f8f8};
-    static mmx_t mmx_greenmask = {0xf8f8f8f8f8f8f8f8};
-    static mmx_t mmx_redmask = {0xf8f8f8f8f8f8f8f8};
+    static mmx_t mmx_bluemask = {0xf8f8f8f8f8f8f8f8ULL};
+    static mmx_t mmx_greenmask = {0xf8f8f8f8f8f8f8f8ULL};
+    static mmx_t mmx_redmask = {0xf8f8f8f8f8f8f8f8ULL};
 
     /*
      * convert RGB plane to RGB 15 bits
@@ -326,7 +361,7 @@ static inline void mmx_unpack_32bgr (uint8_t * image, int cpu)
 
     /* scheduling: this is hopeless */
     movntq (mm6, *image);
-    movq_r2r (mm0, mm6);
+    movq_r2r (mm1, mm6);
     punpcklbw_r2r (mm2, mm6);
     punpckhwd_r2r (mm7, mm6);
     movntq (mm6, *(image+8));
@@ -334,7 +369,7 @@ static inline void mmx_unpack_32bgr (uint8_t * image, int cpu)
     punpckhbw_r2r (mm3, mm5);
     punpcklwd_r2r (mm5, mm4);
     movntq (mm4, *(image+16));
-    movq_r2r (mm0, mm4);
+    movq_r2r (mm1, mm4);
     punpckhbw_r2r (mm2, mm4);
     punpckhwd_r2r (mm5, mm4);
     movntq (mm4, *(image+24));
@@ -342,6 +377,9 @@ static inline void mmx_unpack_32bgr (uint8_t * image, int cpu)
 
 static inline void mmx_unpack_24rgb (uint8_t * image, int cpu)
 {
+    static mmx_t mmx_hirgb = {0x00ffffff00000000ULL};
+    static mmx_t mmx_lorgb = {0x0000000000ffffffULL};
+
     /*
      * convert RGB plane to RGB packed format,
      * mm0 -> B, mm1 -> R, mm2 -> G, mm3 -> 0,
@@ -349,28 +387,67 @@ static inline void mmx_unpack_24rgb (uint8_t * image, int cpu)
      * mm6 -> GB, mm7 -> AR pixel 0-3
      */
 
-    pxor_r2r (mm3, mm3);
     movq_r2r (mm0, mm6);
-
     punpcklbw_r2r (mm2, mm6);
-    movq_r2r (mm1, mm7);
 
-    punpcklbw_r2r (mm3, mm7);
-    movq_r2r (mm0, mm4);
+    movq_r2r (mm1, mm7);
+    punpcklbw_r2r (mm7, mm7);
 
     punpcklwd_r2r (mm7, mm6);
-    movq_r2r (mm1, mm5);
-
-    /* scheduling: this is hopeless */
-    movntq (mm6, *image);
+    movq_r2r (mm6, mm5);
+    pand_m2r (mmx_hirgb, mm5);
+    pand_m2r (mmx_lorgb, mm6);
+    psrlq_i2r (8, mm5);
+    por_r2r(mm6, mm5); /* mm5 = 0x0000R1G1B1R0G0B0 */
+    
     movq_r2r (mm0, mm6);
     punpcklbw_r2r (mm2, mm6);
-    punpckhwd_r2r (mm7, mm6);
-    movntq (mm6, *(image+8));
+    punpckhwd_r2r (mm7, mm6); /* mm6 = 0x??R3G3B3??R2G2B2 */
+
+    movq_r2r (mm6, mm4);
+    psllq_i2r (48, mm4);
+    por_r2r(mm4, mm5);  /* mm5 = 0xG2B2R1G1B1R0G0B0 */
+    movntq (mm5, *image);
+
+    movq_r2r (mm6, mm3);
+    pand_m2r (mmx_hirgb, mm3);
+    pand_m2r (mmx_lorgb, mm6);
+    psrlq_i2r (8, mm3);
+    por_r2r(mm6, mm3); /* mm3 = 0x0000R3G3B3R2G2B2 */
+    psrlq_i2r (16, mm3); /* mm3 = 0x00000000R3G3B3R2 */
+
+    movq_r2r (mm0, mm4);
     punpckhbw_r2r (mm2, mm4);
+    movq_r2r (mm1, mm5);
     punpckhbw_r2r (mm3, mm5);
     punpcklwd_r2r (mm5, mm4);
-    movntq (mm4, *(image+16));
+
+    movq_r2r (mm4, mm6);
+    pand_m2r (mmx_hirgb, mm6);
+    pand_m2r (mmx_lorgb, mm4);
+    psrlq_i2r (8, mm6);
+    por_r2r(mm4, mm6); /* mm6 = 0x0000R5G5B5R4G4B4 */
+
+    movq_r2r (mm6, mm4);
+    psllq_i2r (32, mm4); /* mm4 = 0xB5R4G4B400000000 */
+    por_r2r(mm4, mm3);   /* mm4 = 0xB5R4G4B4R3G3B3R2 */
+    movntq (mm3, *(image+8));
+
+    psrlq_i2r (32, mm6); /* mm6 = 0x000000000000R5G5 */
+
+    movq_r2r (mm0, mm4);
+    punpckhbw_r2r (mm2, mm4);
+    punpckhwd_r2r (mm5, mm4);
+
+    movq_r2r (mm4, mm3);
+    pand_m2r (mmx_hirgb, mm3);
+    pand_m2r (mmx_lorgb, mm4);
+    psrlq_i2r (8, mm3);
+    por_r2r (mm4, mm3);  /* mm3 = 0x0000R7G7B7R6G6B6 */
+    psllq_i2r (16, mm3); /* mm3 = 0xR7G7B7R6G6B60000 */
+    por_r2r (mm3, mm6);  /* mm6 = 0xR7G7B7R6G6B6R5G5 */
+
+    movntq (mm6, *(image+16));
 }
 
 static inline void yuv420_rgb16 (yuv2rgb_t *this,
@@ -378,18 +455,17 @@ static inline void yuv420_rgb16 (yuv2rgb_t *this,
 				 uint8_t * py, uint8_t * pu, uint8_t * pv,
 				 int cpu)
 {
-    int i;
+    int i, height, dst_height;
     int rgb_stride = this->rgb_stride;
     int y_stride   = this->y_stride;
     int uv_stride  = this->uv_stride;
     int width      = this->source_width;
-    int height     = this->slice_height;
-    int dst_height = this->next_slice (this, &image);
     uint8_t *img;
 
     width >>= 3;
 
     if (!this->do_scale) {
+      height = this->next_slice (this, &image);
       y_stride -= 8 * width;
       uv_stride -= 4 * width;
 
@@ -397,7 +473,7 @@ static inline void yuv420_rgb16 (yuv2rgb_t *this,
 
 	i = width; img = image;
 	do {
-	  mmx_yuv2rgb (py, pu, pv); 
+	  mmx_yuv2rgb (py, pu, pv, this->table_mmx);
 	  mmx_unpack_16rgb (img, cpu); 
 	  py += 8;
 	  pu += 4;
@@ -428,6 +504,9 @@ static inline void yuv420_rgb16 (yuv2rgb_t *this,
 		  this->dest_width >> 1, this->step_dx);
       scale_line (py, this->y_buffer, 
 		  this->dest_width, this->step_dx);
+
+      dst_height = this->next_slice (this, &image);
+
       for (height = 0;; ) {
 
 	y_buf = this->y_buffer;
@@ -438,7 +517,7 @@ static inline void yuv420_rgb16 (yuv2rgb_t *this,
 	do {
 	  /* printf ("i : %d\n",i); */
 
-	  mmx_yuv2rgb (y_buf, u_buf, v_buf); 
+	  mmx_yuv2rgb (y_buf, u_buf, v_buf, this->table_mmx);
 	  mmx_unpack_16rgb (img, cpu); 
 	  y_buf += 8;
 	  u_buf += 4;
@@ -489,18 +568,17 @@ static inline void yuv420_rgb15 (yuv2rgb_t *this,
 				 uint8_t * py, uint8_t * pu, uint8_t * pv,
 				 int cpu)
 {
-    int i;
+    int i, height, dst_height;
     int rgb_stride = this->rgb_stride;
     int y_stride   = this->y_stride;
     int uv_stride  = this->uv_stride;
     int width      = this->source_width;
-    int height     = this->slice_height;
-    int dst_height = this->next_slice (this, &image);
     uint8_t *img;
 
     width >>= 3;
 
     if (!this->do_scale) {
+      height = this->next_slice (this, &image);
       y_stride -= 8 * width;
       uv_stride -= 4 * width;
 
@@ -508,7 +586,7 @@ static inline void yuv420_rgb15 (yuv2rgb_t *this,
 
 	i = width; img = image;
 	do {
-	  mmx_yuv2rgb (py, pu, pv); 
+	  mmx_yuv2rgb (py, pu, pv, this->table_mmx);
 	  mmx_unpack_15rgb (img, cpu); 
 	  py += 8;
 	  pu += 4;
@@ -539,6 +617,9 @@ static inline void yuv420_rgb15 (yuv2rgb_t *this,
 		  this->dest_width >> 1, this->step_dx);
       scale_line (py, this->y_buffer, 
 		  this->dest_width, this->step_dx);
+      
+      dst_height = this->next_slice (this, &image);
+      
       for (height = 0;; ) {
 
 	y_buf = this->y_buffer;
@@ -549,7 +630,7 @@ static inline void yuv420_rgb15 (yuv2rgb_t *this,
 	do {
 	  /* printf ("i : %d\n",i); */
 
-	  mmx_yuv2rgb (y_buf, u_buf, v_buf); 
+	  mmx_yuv2rgb (y_buf, u_buf, v_buf, this->table_mmx);
 	  mmx_unpack_15rgb (img, cpu); 
 	  y_buf += 8;
 	  u_buf += 4;
@@ -598,26 +679,25 @@ static inline void yuv420_rgb24 (yuv2rgb_t *this,
 				 uint8_t * image, uint8_t * py,
 				 uint8_t * pu, uint8_t * pv, int cpu)
 {
-    int i;
+    int i, height, dst_height;
     int rgb_stride = this->rgb_stride;
     int y_stride   = this->y_stride;
     int uv_stride  = this->uv_stride;
     int width      = this->source_width;
-    int height     = this->slice_height;
-    int dst_height = this->next_slice (this, &image);
     uint8_t *img;
 
     /* rgb_stride -= 4 * this->dest_width; */
     width >>= 3;
 
     if (!this->do_scale) {
+      height = this->next_slice (this, &image);
       y_stride -= 8 * width;
       uv_stride -= 4 * width;
 
       do {
 	i = width; img = image;
 	do {
-	  mmx_yuv2rgb (py, pu, pv);
+	  mmx_yuv2rgb (py, pu, pv, this->table_mmx);
 	  mmx_unpack_24rgb (img, cpu);
 	  py += 8;
 	  pu += 4;
@@ -648,6 +728,8 @@ static inline void yuv420_rgb24 (yuv2rgb_t *this,
       scale_line (py, this->y_buffer, 
 		  this->dest_width, this->step_dx);
 
+      dst_height = this->next_slice (this, &image);
+
       for (height = 0;; ) {
 
 	y_buf = this->y_buffer;
@@ -659,7 +741,7 @@ static inline void yuv420_rgb24 (yuv2rgb_t *this,
 	do {
 	  /* printf ("i : %d\n",i); */
 
-	  mmx_yuv2rgb (y_buf, u_buf, v_buf); 
+	  mmx_yuv2rgb (y_buf, u_buf, v_buf, this->table_mmx);
 	  mmx_unpack_24rgb (img, cpu); 
 	  y_buf += 8;
 	  u_buf += 4;
@@ -709,26 +791,25 @@ static inline void yuv420_argb32 (yuv2rgb_t *this,
 				  uint8_t * image, uint8_t * py,
 				  uint8_t * pu, uint8_t * pv, int cpu)
 {
-    int i;
+    int i, height, dst_height;
     int rgb_stride = this->rgb_stride;
     int y_stride   = this->y_stride;
     int uv_stride  = this->uv_stride;
     int width      = this->source_width;
-    int height     = this->slice_height;
-    int dst_height = this->next_slice (this, &image);
     uint8_t *img;
 
     /* rgb_stride -= 4 * this->dest_width; */
     width >>= 3;
 
     if (!this->do_scale) {
+      height = this->next_slice (this, &image);
       y_stride -= 8 * width;
       uv_stride -= 4 * width;
 
       do {
 	i = width; img = image;
 	do {
-	  mmx_yuv2rgb (py, pu, pv);
+	  mmx_yuv2rgb (py, pu, pv, this->table_mmx);
 	  mmx_unpack_32rgb (img, cpu);
 	  py += 8;
 	  pu += 4;
@@ -759,6 +840,8 @@ static inline void yuv420_argb32 (yuv2rgb_t *this,
       scale_line (py, this->y_buffer, 
 		  this->dest_width, this->step_dx);
 
+      dst_height = this->next_slice (this, &image);
+      
       for (height = 0;; ) {
 
 	y_buf = this->y_buffer;
@@ -770,7 +853,7 @@ static inline void yuv420_argb32 (yuv2rgb_t *this,
 	do {
 	  /* printf ("i : %d\n",i); */
 
-	  mmx_yuv2rgb (y_buf, u_buf, v_buf); 
+	  mmx_yuv2rgb (y_buf, u_buf, v_buf, this->table_mmx);
 	  mmx_unpack_32rgb (img, cpu); 
 	  y_buf += 8;
 	  u_buf += 4;
@@ -819,26 +902,25 @@ static inline void yuv420_abgr32 (yuv2rgb_t *this,
 				  uint8_t * image, uint8_t * py,
 				  uint8_t * pu, uint8_t * pv, int cpu)
 {
-    int i;
+    int i, height, dst_height;
     int rgb_stride = this->rgb_stride;
     int y_stride   = this->y_stride;
     int uv_stride  = this->uv_stride;
     int width      = this->source_width;
-    int height     = this->slice_height;
-    int dst_height = this->next_slice (this, &image);
     uint8_t *img;
 
     /* rgb_stride -= 4 * this->dest_width; */
     width >>= 3;
 
     if (!this->do_scale) {
+      height = this->next_slice (this, &image);
       y_stride -= 8 * width;
       uv_stride -= 4 * width;
 
       do {
 	i = width; img = image;
 	do {
-	  mmx_yuv2rgb (py, pu, pv);
+	  mmx_yuv2rgb (py, pu, pv, this->table_mmx);
 	  mmx_unpack_32bgr (img, cpu);
 	  py += 8;
 	  pu += 4;
@@ -869,6 +951,8 @@ static inline void yuv420_abgr32 (yuv2rgb_t *this,
       scale_line (py, this->y_buffer, 
 		  this->dest_width, this->step_dx);
 
+      dst_height = this->next_slice (this, &image);
+      
       for (height = 0;; ) {
 
 	y_buf = this->y_buffer;
@@ -880,7 +964,7 @@ static inline void yuv420_abgr32 (yuv2rgb_t *this,
 	do {
 	  /* printf ("i : %d\n",i); */
 
-	  mmx_yuv2rgb (y_buf, u_buf, v_buf); 
+	  mmx_yuv2rgb (y_buf, u_buf, v_buf, this->table_mmx);
 	  mmx_unpack_32bgr (img, cpu); 
 	  y_buf += 8;
 	  u_buf += 4;
