@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: audio_decoder.c,v 1.137 2006/02/05 16:41:16 miguelfreitas Exp $
+ * $Id: audio_decoder.c,v 1.139 2007/02/20 00:34:57 dgp85 Exp $
  *
  *
  * functions that implement audio decoding
@@ -67,7 +67,7 @@ static void *audio_decoder_loop (void *stream_gen) {
     if( !replaying_headers )
       buf = stream->audio_fifo->get (stream->audio_fifo);
 
-    lprintf ("audio_loop: got package pts = %lld, type = %08x\n", buf->pts, buf->type); 
+    lprintf ("audio_loop: got package pts = %"PRId64", type = %08x\n", buf->pts, buf->type); 
 
     _x_extra_info_merge( stream->audio_decoder_extra_info, buf->extra_info );
     stream->audio_decoder_extra_info->seek_count = stream->video_seek_count;
@@ -459,7 +459,7 @@ static void *audio_decoder_loop (void *stream_gen) {
   return NULL;
 }
 
-void _x_audio_decoder_init (xine_stream_t *stream) {
+int _x_audio_decoder_init (xine_stream_t *stream) {
 
   pthread_attr_t       pth_attrs;
   struct sched_param   pth_params;
@@ -467,7 +467,7 @@ void _x_audio_decoder_init (xine_stream_t *stream) {
 
   if (stream->audio_out == NULL) {
     stream->audio_fifo = _x_dummy_fifo_buffer_new (5, 8192);
-    return;
+    return 1;
   } else {
     int num_buffers;
     
@@ -510,11 +510,14 @@ void _x_audio_decoder_init (xine_stream_t *stream) {
                                &pth_attrs, audio_decoder_loop, stream)) != 0) {
       xprintf (stream->xine, XINE_VERBOSITY_DEBUG, 
 	       "audio_decoder: can't create new thread (%s)\n", strerror(err));
-      _x_abort();
+      stream->audio_thread_created = 0;
+      pthread_attr_destroy(&pth_attrs);
+      return 0;
     }
   
     pthread_attr_destroy(&pth_attrs);
   }
+  return 1;
 }
 
 void _x_audio_decoder_shutdown (xine_stream_t *stream) {
