@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: buffer.h,v 1.145 2004/12/12 22:01:30 mroi Exp $
+ * $Id: buffer.h,v 1.162 2007/01/14 16:53:37 klan Exp $
  *
  *
  * contents:
@@ -74,18 +74,19 @@ extern "C" {
 
 /* control buffer types */
 
-#define BUF_CONTROL_BASE          0x01000000
-#define BUF_CONTROL_START         0x01000000
-#define BUF_CONTROL_END           0x01010000
-#define BUF_CONTROL_QUIT          0x01020000
-#define BUF_CONTROL_DISCONTINUITY 0x01030000 /* former AVSYNC_RESET */
-#define BUF_CONTROL_NOP           0x01040000
-#define BUF_CONTROL_AUDIO_CHANNEL 0x01050000
-#define BUF_CONTROL_SPU_CHANNEL   0x01060000
-#define BUF_CONTROL_NEWPTS        0x01070000
-#define BUF_CONTROL_RESET_DECODER 0x01080000
-#define BUF_CONTROL_HEADERS_DONE  0x01090000
-#define BUF_CONTROL_FLUSH_DECODER 0x010a0000
+#define BUF_CONTROL_BASE            0x01000000
+#define BUF_CONTROL_START           0x01000000
+#define BUF_CONTROL_END             0x01010000
+#define BUF_CONTROL_QUIT            0x01020000
+#define BUF_CONTROL_DISCONTINUITY   0x01030000 /* former AVSYNC_RESET */
+#define BUF_CONTROL_NOP             0x01040000
+#define BUF_CONTROL_AUDIO_CHANNEL   0x01050000
+#define BUF_CONTROL_SPU_CHANNEL     0x01060000
+#define BUF_CONTROL_NEWPTS          0x01070000
+#define BUF_CONTROL_RESET_DECODER   0x01080000
+#define BUF_CONTROL_HEADERS_DONE    0x01090000
+#define BUF_CONTROL_FLUSH_DECODER   0x010a0000
+#define BUF_CONTROL_RESET_TRACK_MAP 0x010b0000
 
 /* video buffer types:  (please keep in sync with buffer_types.c) */
 
@@ -168,6 +169,28 @@ extern "C" {
 #define BUF_VIDEO_BITPLANE_BR1	0x024B0000 /* the same with Bytrun compression 1 */
 #define BUF_VIDEO_FLV1		0x024C0000
 #define BUF_VIDEO_H264		0x024D0000
+#define BUF_VIDEO_MJPEG_B	0x024E0000
+#define BUF_VIDEO_H261		0x024F0000
+#define BUF_VIDEO_AASC		0x02500000
+#define BUF_VIDEO_LOCO		0x02510000
+#define BUF_VIDEO_QDRW		0x02520000
+#define BUF_VIDEO_QPEG		0x02530000
+#define BUF_VIDEO_ULTI		0x02540000
+#define BUF_VIDEO_WNV1		0x02550000
+#define BUF_VIDEO_XL		0x02560000
+#define BUF_VIDEO_RT21		0x02570000
+#define BUF_VIDEO_FPS1		0x02580000
+#define BUF_VIDEO_DUCKTM2	0x02590000
+#define BUF_VIDEO_CSCD		0x025A0000
+#define BUF_VIDEO_ALGMM		0x025B0000
+#define BUF_VIDEO_ZMBV		0x025C0000
+#define BUF_VIDEO_AVS		0x025D0000
+#define BUF_VIDEO_SMACKER	0x025E0000
+#define BUF_VIDEO_NUV		0x025F0000
+#define BUF_VIDEO_KMVC		0x02600000
+#define BUF_VIDEO_FLASHSV	0x02610000
+#define BUF_VIDEO_CAVS		0x02620000
+#define BUF_VIDEO_VP6F		0x02630000
 
 /* audio buffer types:  (please keep in sync with buffer_types.c) */
 
@@ -226,6 +249,15 @@ extern "C" {
 #define BUF_AUDIO_VMD		0x03320000
 #define BUF_AUDIO_XAN_DPCM	0x03330000
 #define BUF_AUDIO_ALAC		0x03340000
+#define BUF_AUDIO_MPC		0x03350000
+#define BUF_AUDIO_SHORTEN	0x03360000
+#define BUF_AUDIO_WESTWOOD_SND1	0x03370000
+#define BUF_AUDIO_WMALL		0x03380000
+#define BUF_AUDIO_TRUESPEECH	0x03390000
+#define BUF_AUDIO_TTA		0x033A0000
+#define BUF_AUDIO_SMACKER	0x033B0000
+#define BUF_AUDIO_FLVADPCM	0x033C0000
+#define BUF_AUDIO_WAVPACK	0x033D0000
 
 /* spu buffer types:    */
 
@@ -268,7 +300,7 @@ struct extra_info_s {
 };
 
 
-#define BUF_NUM_DEC_INFO 4
+#define BUF_NUM_DEC_INFO 5
 
 typedef struct buf_element_s buf_element_t;
 struct buf_element_s {
@@ -574,24 +606,24 @@ struct fifo_buffer_s
  * allocate num_buffers of buf_size bytes each
  */
 
-fifo_buffer_t *_x_fifo_buffer_new (int num_buffers, uint32_t buf_size);
-fifo_buffer_t *_x_dummy_fifo_buffer_new (int num_buffers, uint32_t buf_size);
+fifo_buffer_t *_x_fifo_buffer_new (int num_buffers, uint32_t buf_size) XINE_PROTECTED;
+fifo_buffer_t *_x_dummy_fifo_buffer_new (int num_buffers, uint32_t buf_size) XINE_PROTECTED;
 
 
 /* return BUF_VIDEO_xxx given the fourcc
  * fourcc_int must be read in machine endianness
  * example: fourcc_int = *(uint32_t *)fourcc_char;
  */
-uint32_t _x_fourcc_to_buf_video( uint32_t fourcc_int );
+uint32_t _x_fourcc_to_buf_video( uint32_t fourcc_int ) XINE_PROTECTED;
 
 /* return codec name given BUF_VIDEO_xxx */
-char * _x_buf_video_name( uint32_t buf_type );
+char * _x_buf_video_name( uint32_t buf_type ) XINE_PROTECTED;
 
-/* return BUF_VIDEO_xxx given the formattag */
-uint32_t _x_formattag_to_buf_audio( uint32_t formattag );
+/* return BUF_AUDIO_xxx given the formattag */
+uint32_t _x_formattag_to_buf_audio( uint32_t formattag ) XINE_PROTECTED;
 
-/* return codec name given BUF_VIDEO_xxx */
-char * _x_buf_audio_name( uint32_t buf_type );
+/* return codec name given BUF_AUDIO_xxx */
+char * _x_buf_audio_name( uint32_t buf_type ) XINE_PROTECTED;
 
 
 #ifndef ATTRIBUTE_PACKED
@@ -634,10 +666,10 @@ typedef struct __attribute__((__packed__)) {
 #endif
 
 /* convert xine_bmiheader struct from little endian */
-void _x_bmiheader_le2me( xine_bmiheader *bih );
+void _x_bmiheader_le2me( xine_bmiheader *bih ) XINE_PROTECTED;
 
 /* convert xine_waveformatex struct from little endian */
-void _x_waveformatex_le2me( xine_waveformatex *wavex );
+void _x_waveformatex_le2me( xine_waveformatex *wavex ) XINE_PROTECTED;
 
 #ifdef __cplusplus
 }
