@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: buffer_types.c,v 1.106 2006/10/02 15:56:06 valtri Exp $
+ * $Id: buffer_types.c,v 1.107 2006/12/26 03:18:56 dgp85 Exp $
  *
  *
  * contents:
@@ -49,17 +49,17 @@
 typedef struct video_db_s {
    uint32_t fourcc[20];
    uint32_t buf_type;
-   char *name;
+   const char *name;
 } video_db_t;
 
 typedef struct audio_db_s {
    uint32_t formattag[10];
    uint32_t buf_type;
-   char *name;
+   const char *name;
 } audio_db_t;
 
 
-static video_db_t video_db[] = {
+static const video_db_t video_db[] = {
 {
   {
     meFOURCC('m', 'p', 'e', 'g'),
@@ -767,7 +767,7 @@ static video_db_t video_db[] = {
 };
 
 
-static audio_db_t audio_db[] = {
+static const audio_db_t audio_db[] = {
 {
   {
     0x2000,
@@ -1114,6 +1114,13 @@ static audio_db_t audio_db[] = {
   BUF_AUDIO_MPC,
   "Musepack"
 },
+{
+  {
+    0
+  },
+  BUF_AUDIO_WAVPACK,
+  "Wavpack"
+},
 { { 0 }, 0, "last entry" }
 };
 
