@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: configfile.h,v 1.39 2006/12/19 19:10:52 dsalt Exp $
+ * $Id: configfile.h,v 1.42 2007/02/22 15:49:16 dgp85 Exp $
  *
  * config file management
  *
@@ -163,7 +163,7 @@ struct config_values_s {
   void (*update_string) (config_values_t *self, const char *key, const char *value);
 
   /* small utility function for enum handling */
-  int (*parse_enum) (const char *str, char **values);
+  int (*parse_enum) (const char *str, const char **values);
 
   /*
    * lookup config entries
