@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: events.c,v 1.26.2.1 2005/07/17 21:50:14 miguelfreitas Exp $
+ * $Id: events.c,v 1.32 2006/10/16 22:18:24 valtri Exp $
  *
  * Event handling functions
  *
@@ -33,14 +33,16 @@
 
 xine_event_t *xine_event_get  (xine_event_queue_t *queue) {
 
-  xine_event_t  *event;
+  xine_event_t  *event = NULL;
+  xine_list_iterator_t ite;
 
   pthread_mutex_lock (&queue->lock);
-
-  event = (xine_event_t *) xine_list_first_content (queue->events);
-  if (event)
-    xine_list_delete_current (queue->events);
-
+  ite = xine_list_front (queue->events);
+  if (ite) {
+    event = xine_list_get_value (queue->events, ite);
+    if (event)
+      xine_list_remove (queue->events, ite);
+  }
   pthread_mutex_unlock (&queue->lock);
 
   return event;
@@ -49,14 +51,17 @@ xine_event_t *xine_event_get  (xine_event_queue_t *queue) {
 xine_event_t *xine_event_wait (xine_event_queue_t *queue) {
 
   xine_event_t  *event;
+  xine_list_iterator_t ite;
 
   pthread_mutex_lock (&queue->lock);
 
-  while (!(event = (xine_event_t *) xine_list_first_content (queue->events))) {
+  while ( !(ite = xine_list_front (queue->events)) ) {
     pthread_cond_wait (&queue->new_event, &queue->lock);
   }
 
-  xine_list_delete_current (queue->events);
+  event = xine_list_get_value (queue->events, ite);
+
+  xine_list_remove (queue->events, ite);
 
   pthread_mutex_unlock (&queue->lock);
 
@@ -70,16 +75,17 @@ void xine_event_free (xine_event_t *event) {
 
 void xine_event_send (xine_stream_t *stream, const xine_event_t *event) {
 
-  xine_event_queue_t *queue;
+  xine_list_iterator_t ite;
 
   pthread_mutex_lock (&stream->event_queues_lock);
 
-  queue = (xine_event_queue_t *)xine_list_first_content (stream->event_queues);
+  ite = xine_list_front (stream->event_queues);
 
-  while (queue) {
-    
+  while (ite) {
+    xine_event_queue_t *queue;
     xine_event_t *cevent;
 
+    queue = xine_list_get_value(stream->event_queues, ite);
     cevent = malloc (sizeof (xine_event_t));
     cevent->type        = event->type;
     cevent->stream      = stream;
@@ -93,11 +99,11 @@ void xine_event_send (xine_stream_t *stream, const xine_event_t *event) {
     gettimeofday (&cevent->tv, NULL);
     
     pthread_mutex_lock (&queue->lock);
-    xine_list_append_content (queue->events, cevent);
+    xine_list_push_back (queue->events, cevent);
     pthread_cond_signal (&queue->new_event);
     pthread_mutex_unlock (&queue->lock);
 
-    queue=(xine_event_queue_t *)xine_list_next_content (stream->event_queues);
+    ite = xine_list_next (stream->event_queues, ite);
   }
 
   pthread_mutex_unlock (&stream->event_queues_lock);
@@ -119,7 +125,7 @@ xine_event_queue_t *xine_event_new_queue (xine_stream_t *stream) {
   queue->callback_running = 0;
 
   pthread_mutex_lock (&stream->event_queues_lock);
-  xine_list_append_content (stream->event_queues, queue);
+  xine_list_push_back (stream->event_queues, queue);
   pthread_mutex_unlock (&stream->event_queues_lock);
 
   return queue;
@@ -127,26 +133,34 @@ xine_event_queue_t *xine_event_new_queue (xine_stream_t *stream) {
 
 void xine_event_dispose_queue (xine_event_queue_t *queue) {
 
-  xine_stream_t      *stream = queue->stream;
-  xine_event_t       *event;
-  xine_event_t       *qevent;
-  xine_event_queue_t *q;
+  xine_stream_t        *stream = queue->stream;
+  xine_event_t         *event;
+  xine_event_t         *qevent;
+  xine_event_queue_t   *q;
+  xine_list_iterator_t  ite;
     
   pthread_mutex_lock (&stream->event_queues_lock);
 
-  q = (xine_event_queue_t *) xine_list_first_content (stream->event_queues);
+  ite = xine_list_front (stream->event_queues);
 
-  while (q && (q != queue))
-    q = (xine_event_queue_t *) xine_list_next_content (stream->event_queues);
+  q = NULL;
+  if ( ite ) {
+    do {
+      q = xine_list_get_value (stream->event_queues, ite);
+      
+      if ( q == queue )
+	break;
+    } while( (ite = xine_list_next (stream->event_queues, ite)) );
+  }
 
-  if (!q) {
+  if (q != queue) {
     xprintf (stream->xine, XINE_VERBOSITY_DEBUG, "events: tried to dispose queue which is not in list\n");
 
     pthread_mutex_unlock (&stream->event_queues_lock);
     return;
   }
 
-  xine_list_delete_current (stream->event_queues);
+  xine_list_remove (stream->event_queues, ite);
   pthread_mutex_unlock (&stream->event_queues_lock);
 
   /* 
@@ -161,7 +175,7 @@ void xine_event_dispose_queue (xine_event_queue_t *queue) {
   gettimeofday (&qevent->tv, NULL);
   
   pthread_mutex_lock (&queue->lock);
-  xine_list_append_content (queue->events, qevent);
+  xine_list_push_back (queue->events, qevent);
   pthread_cond_signal (&queue->new_event);
   pthread_mutex_unlock (&queue->lock);
 
@@ -183,6 +197,10 @@ void xine_event_dispose_queue (xine_event_queue_t *queue) {
     xine_event_free (event);
   }
 
+  pthread_mutex_destroy(&queue->lock);
+  pthread_cond_destroy(&queue->new_event);
+  pthread_cond_destroy(&queue->events_processed);
+
   free (queue);
 }
 
@@ -208,7 +226,7 @@ static void *listener_loop (void *queue_gen) {
     xine_event_free (event);
 
     pthread_mutex_lock (&queue->lock);
-    if (xine_list_is_empty (queue->events)) {
+    if (xine_list_empty (queue->events)) {
       pthread_cond_signal (&queue->events_processed);
     }
     pthread_mutex_unlock (&queue->lock);
