@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2000-2004 the xine project
+ * Copyright (C) 2000-2005 the xine project
  *
  * This file is part of xine, a free video player.
  * 
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: video_decoder.c,v 1.155.2.1 2005/04/20 17:21:16 mroi Exp $
+ * $Id: video_decoder.c,v 1.163 2007/02/20 00:34:58 dgp85 Exp $
  *
  */
 
@@ -153,8 +153,9 @@ static void *video_decoder_loop (void *stream_gen) {
       
       running_ticket->release(running_ticket, 0);
       
-      stream->metronom->handle_video_discontinuity (stream->metronom, 
-						    DISC_STREAMSTART, 0);
+      if( !stream->gapless_switch )
+        stream->metronom->handle_video_discontinuity (stream->metronom, 
+						      DISC_STREAMSTART, 0);
       
       buftype_unknown = 0;
       break;
@@ -189,11 +190,16 @@ static void *video_decoder_loop (void *stream_gen) {
           stream->video_decoder_plugin->flush (stream->video_decoder_plugin);
         running_ticket->release(running_ticket, 0);
       }
-      
+
       /*
        * wait the output fifos to run dry before sending the notification event
-       * to the frontend. this test is only valid if there is only a single
-       * stream attached to the current output port.
+       * to the frontend. exceptions:
+       * 1) don't wait if there is more than one stream attached to the current
+       *    output port (the other stream might be sending data so we would be
+       *    here forever)
+       * 2) early_finish_event: send notification asap to allow gapless switch
+       * 3) slave stream: don't wait. get into an unblocked state asap to allow
+       *    new master actions.
        */
       while(1) {
         int num_bufs, num_streams;
@@ -203,7 +209,8 @@ static void *video_decoder_loop (void *stream_gen) {
         num_streams = stream->video_out->get_property(stream->video_out, VO_PROP_NUM_STREAMS);
         running_ticket->release(running_ticket, 0);
         
-        if( num_bufs > 0 && num_streams == 1 )
+        if( num_bufs > 0 && num_streams == 1 && !stream->early_finish_event &&
+            stream->master == stream )
           xine_usec_sleep (10000);
         else
           break;
@@ -220,7 +227,7 @@ static void *video_decoder_loop (void *stream_gen) {
 
       pthread_cond_broadcast (&stream->counter_changed);
 
-      if (stream->audio_thread) {
+      if (stream->audio_thread_created) {
 
         while (stream->finished_count_video > stream->finished_count_audio) {
           struct timeval tv;
@@ -301,7 +308,7 @@ static void *video_decoder_loop (void *stream_gen) {
       break;
     
     case BUF_CONTROL_NEWPTS:
-      lprintf ("new pts %lld\n", buf->disc_off);
+      lprintf ("new pts %"PRId64"\n", buf->disc_off);
 
       if (stream->video_decoder_plugin) {
         running_ticket->acquire(running_ticket, 0);
@@ -463,12 +470,12 @@ static void *video_decoder_loop (void *stream_gen) {
   return NULL;
 }
 
-void _x_video_decoder_init (xine_stream_t *stream) {
+int _x_video_decoder_init (xine_stream_t *stream) {
   
   if (stream->video_out == NULL) {
     stream->video_fifo = _x_dummy_fifo_buffer_new (5, 8192);
     stream->spu_track_map_entries = 0;
-    return;
+    return 1;
   } else {
      
     pthread_attr_t       pth_attrs;
@@ -493,6 +500,11 @@ void _x_video_decoder_init (xine_stream_t *stream) {
                                                       20, NULL, NULL);
   
     stream->video_fifo = _x_fifo_buffer_new (num_buffers, 8192);
+    if (stream->video_fifo == NULL) {
+      xine_log(stream->xine, XINE_LOG_MSG, "video_decoder: can't allocated video fifo\n");
+      return 0;
+    }
+    
     stream->spu_track_map_entries = 0;
   
     pthread_attr_init(&pth_attrs);
@@ -500,16 +512,20 @@ void _x_video_decoder_init (xine_stream_t *stream) {
     pth_params.sched_priority = sched_get_priority_min(SCHED_OTHER);
     pthread_attr_setschedparam(&pth_attrs, &pth_params);
     pthread_attr_setscope(&pth_attrs, PTHREAD_SCOPE_SYSTEM);
-    
+
+    stream->video_thread_created = 1;
     if ((err = pthread_create (&stream->video_thread,
                                &pth_attrs, video_decoder_loop, stream)) != 0) {
-      fprintf (stderr, "video_decoder: can't create new thread (%s)\n",
-               strerror(err));
-      _x_abort();
+      xine_log (stream->xine, XINE_LOG_MSG, "video_decoder: can't create new thread (%s)\n",
+                strerror(err));
+      stream->video_thread_created = 0;
+      pthread_attr_destroy(&pth_attrs);
+      return 0;
     }
     
     pthread_attr_destroy(&pth_attrs);
   }
+  return 1;
 }
 
 void _x_video_decoder_shutdown (xine_stream_t *stream) {
@@ -519,7 +535,7 @@ void _x_video_decoder_shutdown (xine_stream_t *stream) {
 
   lprintf ("shutdown...\n");
 
-  if (stream->video_thread) {
+  if (stream->video_thread_created) {
 
     /* stream->video_fifo->clear(stream->video_fifo); */
 
@@ -533,6 +549,7 @@ void _x_video_decoder_shutdown (xine_stream_t *stream) {
     lprintf ("shutdown...3\n");
 
     pthread_join (stream->video_thread, &p);
+    stream->video_thread_created = 0;
 
     lprintf ("shutdown...4\n");
 
