@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: xine_plugin.h,v 1.16.2.1 2005/04/20 17:21:17 mroi Exp $
+ * $Id: xine_plugin.h,v 1.23 2007/01/19 02:49:31 dgp85 Exp $
  *
  * generic plugin definitions
  *
@@ -55,7 +55,7 @@ typedef struct {
   uint8_t                  API;                     /* API version supported by this plugin    */
   char                    *id;                      /* a name that identifies this plugin      */
   uint32_t                 version;                 /* version number, increased every release */
-  void                    *special_info;            /* plugin-type specific, see structs below */
+  const void              *special_info;            /* plugin-type specific, see structs below */
   void                  *(*init)(xine_t *, void *); /* init the plugin class            */
 } plugin_info_t;
 
@@ -73,7 +73,7 @@ typedef struct {
 
 /* special_info for a decoder plugin */
 typedef struct {
-  uint32_t                *supported_types;         /* streamtypes this decoder can handle       */
+  uint32_t          *supported_types;         /* streamtypes this decoder can handle       */
   int                      priority;
 } decoder_info_t;
 
@@ -97,12 +97,12 @@ typedef struct {
  * info is a list of plugin_info_t terminated by PLUGIN_NONE
  * example:
  *   plugin_info_t acme_plugin_info[] = {
- *     { PLUGIN_VIDEO_OUT, 20, "acme", XINE_VERSION_CODE, &vo_info_acme,
+ *     { PLUGIN_VIDEO_OUT, 21, "acme", XINE_VERSION_CODE, &vo_info_acme,
  *   init_class_acme },
  *     { PLUGIN_NONE, 0, "", 0, NULL, NULL }
  *   };
  *
  */
-void xine_register_plugins(xine_t *self, plugin_info_t *info);
+void xine_register_plugins(xine_t *self, plugin_info_t *info) XINE_PROTECTED;
 
 #endif
