@@ -63,7 +63,7 @@ static uint32_t arch_accel (void)
   int AMD;
 
   caps = 0;
-#ifndef PIC
+#ifndef __PIC__
 #define cpuid(op,eax,ebx,ecx,edx)       \
     __asm__ ("cpuid"                    \
          : "=a" (eax),                  \
@@ -189,7 +189,7 @@ static void sigill_handler (int sig)
 static uint32_t arch_accel (void)
 {
   /* FIXME: Autodetect cache line size via AUX ELF vector or otherwise */
-  uint32_t flags = MM_ACCEL_PPC_CACHE32;
+  uint32_t flags = 0;
 
   signal (SIGILL, sigill_handler);
   if (sigsetjmp (jmpbuf, 1)) {
@@ -326,7 +326,7 @@ uint32_t xine_mm_accel (void)
 #endif
 #endif
 
-#if defined(ARCH_X86) || (defined(ARCH_PPC) && defined(ENABLE_ALTIVEC)) || (defined(ARCH_SPARC) && defined(ENABLE_VIS))
+#if defined(ARCH_X86) || defined(ARCH_X86_64) || (defined(ARCH_PPC) && defined(ENABLE_ALTIVEC)) || (defined(ARCH_SPARC) && defined(ENABLE_VIS))
     accel |= arch_accel();
 #endif
 
