@@ -72,11 +72,12 @@
 
 #endif  /* !__linux__ */
 
-static void set_hc_result(xine_health_check_t* hc, int state, char *format, ...) {
+static void XINE_FORMAT_PRINTF(3, 4)
+set_hc_result(xine_health_check_t* hc, int state, const char *format, ...)
+{
 
   va_list   args;
   char     *buf = NULL;
-  int       n, size;
 
   if (!hc) {
     printf ("xine_check: GASP, hc is NULL\n");
@@ -88,33 +89,13 @@ static void set_hc_result(xine_health_check_t* hc, int state, char *format, ...)
     _x_abort();
   }
 
-  size = strlen(format) + 1;
+  va_start(args, format);
+  vasprintf (&buf, format, args);
+  va_end(args);
 
-  if (!(buf = xine_xmalloc(size)))
+  if (!buf)
     _x_abort();
 
-  while(1) {
-    va_start(args, format);
-    n = vsnprintf(buf, size, format, args);
-    va_end(args);
-
-    if(n > -1 && n < size) {
-      break;
-      }
-
-    if(n > -1) {
-      size = n + 1;
-    }
-    else {
-      size *= 2;
-    }
-
-    if((buf = realloc(buf, size)) == NULL) {
-      printf("%s() GASP, realloc() failed\n", __XINE_FUNCTION__);
-      _x_abort();
-    }
-  }
-
   hc->msg         = buf;
   hc->status      = state;
 }
@@ -173,13 +154,12 @@ xine_health_check_t* _x_health_check_kernel (xine_health_check_t* hc) {
 
 #if defined(ARCH_X86) || defined(ARCH_X86_64)
 xine_health_check_t* _x_health_check_mtrr (xine_health_check_t* hc) {
-  char *file = "/proc/mtrr";
   FILE *fd;
 
   hc->title       = "Check for MTRR support";
   hc->explanation = "Make sure your kernel has MTRR support compiled in.";
 
-  fd = fopen(file, "r");
+  fd = fopen("/proc/mtrr", "r");
   if (!fd) {
     set_hc_result (hc, XINE_HEALTH_CHECK_FAIL, 
 		   "FAILED: mtrr is not enabled.");
@@ -206,8 +186,8 @@ xine_health_check_t* _x_health_check_cdrom (xine_health_check_t* hc) {
   int fd;
 
   hc->title       = "Check for CDROM drive";
-  hc->explanation = "Either create a symbolic link /dev/cdrom pointing to"
-                    "your cdrom device or set your cdrom device in the"
+  hc->explanation = "Either create a symbolic link /dev/cdrom pointing to "
+                    "your cdrom device or set your cdrom device in the "
                     "preferences dialog.";
 
   if (stat (hc->cdrom_dev,&cdrom_st) < 0) {
@@ -242,8 +222,8 @@ xine_health_check_t* _x_health_check_dvdrom(xine_health_check_t* hc) {
   int fd;
 
   hc->title       = "Check for DVD drive";
-  hc->explanation = "Either create a symbolic link /dev/dvd pointing to"
-                    "your cdrom device or set your cdrom device in the"
+  hc->explanation = "Either create a symbolic link /dev/dvd pointing to "
+                    "your cdrom device or set your cdrom device in the "
                     "preferences dialog.";
 
   if (stat (hc->dvd_dev,&dvdrom_st) < 0) {
@@ -355,7 +335,7 @@ xine_health_check_t* _x_health_check_xv (xine_health_check_t* hc) {
   Display               *(*xopendisplay)(char*);
   char                  *(*xdisplayname)(char*);
   int                   (*xvqueryextension)(Display*, unsigned int*, unsigned int*, unsigned int*, unsigned int*, unsigned int*);
-  int                   (*xvqueryadaptors)(Display*, Window, unsigned int*, XvAdaptorInfo**);
+  int                   (*xvqueryadaptors)(Display*, Window, int*, XvAdaptorInfo**);
   XvImageFormatValues   *(*xvlistimageformats)(Display*, XvPortID, int*);
   char                  *err = NULL;
   int                   formats, adaptors, i;
@@ -364,12 +344,12 @@ xine_health_check_t* _x_health_check_xv (xine_health_check_t* hc) {
 
   hc->title       = "Check for MIT Xv extension";
   hc->explanation = "You can improve performance by installing an X11\n"
-    "driver that supports the Xv protocol extentsion.";
+    "driver that supports the Xv protocol extension.";
 
   /* Majority of thi code was taken from or inspired by the xvinfo.c file of XFree86 */
 
   dlerror(); /* clear error code */
-  x11_handle = dlopen("libX11.so", RTLD_LAZY);
+  x11_handle = dlopen(LIBX11_SO, RTLD_LAZY);
   if(!x11_handle) {
     hc->msg = dlerror();
     hc->status = XINE_HEALTH_CHECK_FAIL;
@@ -395,7 +375,7 @@ xine_health_check_t* _x_health_check_xv (xine_health_check_t* hc) {
   }
   
   dlerror(); /* clear error code */
-  xv_handle = dlopen("libXv.so", RTLD_LAZY);
+  xv_handle = dlopen(LIBXV_SO, RTLD_LAZY);
   if(!xv_handle) {
     hc->msg = dlerror();
     /* Xv might still work when linked statically into the output plugin,
@@ -502,7 +482,7 @@ xine_health_check_t* _x_health_check_xv (xine_health_check_t* hc) {
 #else
   hc->title       = "Check for MIT Xv extension";
   hc->explanation = "You can improve performance by installing an X11\n"
-    "driver that supports the Xv protocol extentsion.";
+    "driver that supports the Xv protocol extension.";
 
   set_hc_result(hc, XINE_HEALTH_CHECK_FAIL, "No X-Video Extension was present at compile time");
   return hc;
@@ -510,7 +490,7 @@ xine_health_check_t* _x_health_check_xv (xine_health_check_t* hc) {
 #else
   hc->title       = "Check for MIT Xv extension";
   hc->explanation = "You can improve performance by installing an X11\n"
-    "driver that supports the Xv protocol extentsion.";
+    "driver that supports the Xv protocol extension.";
 
   set_hc_result(hc, XINE_HEALTH_CHECK_FAIL, "No X11 windowing system was present at compile time");
   return hc;
