@@ -1,28 +1,34 @@
 /*
- *  Copyright (C) 2002-2003 the xine project
+ *  Copyright (C) 2002-2003,2007 the xine project
  *
  *  This file is part of xine, a free video player.
  *
- *  xine is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * The xine-lib XML parser is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
  *
- *  xine is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * The xine-lib XML parser is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
+ * You should have received a copy of the GNU Library General Public
+ * License along with the Gnome Library; see the file COPYING.LIB.  If not,
+ * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  *
- *  $Id: xmlparser.h,v 1.5 2006/09/26 05:19:49 dgp85 Exp $
+ *  $Id: xmlparser.h,v 1.6 2007/03/04 16:19:12 hadess Exp $
  *
  */
+
 #ifndef XML_PARSER_H
 #define XML_PARSER_H
 
+#ifndef XINE_PROTECTED
+#define XINE_PROTECTED
+#endif
+
 /* parser modes */
 #define XML_PARSER_CASE_INSENSITIVE  0
 #define XML_PARSER_CASE_SENSITIVE    1
@@ -54,7 +60,7 @@ int xml_parser_build_tree(xml_node_t **root_node) XINE_PROTECTED;
 
 void xml_parser_free_tree(xml_node_t *root_node) XINE_PROTECTED;
 
-char *xml_parser_get_property (const xml_node_t *node, const char *name) XINE_PROTECTED;
+const char *xml_parser_get_property (const xml_node_t *node, const char *name) XINE_PROTECTED;
 int   xml_parser_get_property_int (const xml_node_t *node, const char *name, 
 				   int def_value) XINE_PROTECTED;
 int xml_parser_get_property_bool (const xml_node_t *node, const char *name, 
